% The time step needs to be set
% by the options argument, field InitialStep.
% 
% Arguments:
%    rhsfun  = right-hand side function: returns f(t,y) 
%              as a column vector.
%    tspan   = time span (start time, usually zero, 
%              and stop time).
%    y0      = initial condition.
%    h       = step size; constant.
%
%
% Copyright (C) 2009, Petr Krysl
% 
function [ts, ys] = odeimeultrap2nd (rhsfun, tspan, y0, options, varargin)
    h = options.InitialStep(1);
    K=options.K;
    M=options.M;
     F0=zeros(size(M,1));
    F=@(t)F0;
    if isfield( options,'F')
        F=options.F;
    end
    maxit=12;
    if isfield( options,'maxit')
        maxit=options.maxit;
    end
    eta=0;
    if isfield( options,'eta')
        eta=options.eta;
    end
    nsteps = ceil ((tspan(2) - tspan(1)) / h);
    ts = zeros(nsteps+1,1);
    ys = zeros(nsteps+1,length(y0));
    n=length(y0)/2;
    t = tspan(1);
    ts(1) = t;
    ys(1,:) = y0';
    S=(M-eta*(h^2)/2*K);% when the step size changes, this needs to change!  
    E=eye(n); Z=zeros(n);
    F0 =F(ts(1));
    for step = 2:nsteps+1
        if (ts(step-1) + h >tspan(2)), h=tspan(2)-ts(step-1); end
        F1 =F(ts(step-1) + h);
        y0 =ys(step-1,:)';
        %         A = [zeros(n),eye(n);-(M\K),zeros(n)];
        %         L0=[zeros(n,1);M\F0];
        %         L1=[zeros(n,1);M\F1];
        %         y1 =(eye(length(y0))-h/2*(1+eta)*A+h^2/2*eta*A^2)\((eye(length(y0))+h/2*(1-eta)*A)*y0-h^2/2*eta*A*L1+h/2*L0+h/2*L1);
        x0=ys(step-1,1:n)';
        v0=ys(step-1,n+1:end)';
        L0=[zeros(n,1);F0];
        L1=[zeros(n,1);F1];
        AL1=[F1;zeros(n,1)];
        Al = [(M-(h^2)/2*eta*(K)),-h/2*(1+eta)*M;
            h/2*(1+eta)*(K),(M-(h^2)/2*eta*(K))];
%         C=M*((-2*h^2*eta+h^2+h^2*eta^2)*K);
%         B=M*(4*M+h^4*eta^2*M^(-1)*K^2);
%         [V,D]=eig(B\C);
%         plot(abs(diag(D)))

        %         C  = [(M-(h^2)/2*eta*(K)),Z;
        %             Z,(M-(h^2)/2*eta*(K))];
        %         B=  [Z,-h/2*(1+eta)*M;
        %             h/2*(1+eta)*(K),Z];%
        Ar = [M,h/2*(1-eta)*M;-h/2*(1-eta)*(K),M];
        y1 = Al\(Ar*y0-(h^2)/2*eta*AL1+h/2*(L0+L1));
        ts(step) = ts(step-1) + h;
        ys(step,:) = y1';
        F0 =F1;
    end
    return;
end

% % Function to integrate a system of first-order
% % initial-value ODE's by the backward modified Euler method.
% %
% % One Backward Euler step for the equation dy/dt = f(t,y) reads
% %
% % y_n+1 = y_n + h * f(t_n+1, y_n+1)
% %
% % The integrator accepts the same arguments as the built-in
% % Matlab solvers ode23,.  The time step needs to be set
% % by the options argument, field InitialStep.
% %
% % Arguments:
% %    rhsfun  = right-hand side function: returns f(t,y)
% %              as a column vector.
% %    tspan   = time span (start time, usually zero,
% %              and stop time).
% %    y0      = initial condition.
% %    h       = step size; constant.
% %
% %
% % Copyright (C) 2007, Petr Krysl
% %
% function [ts, ys] = odeimeultrap2nd (rhsfun, tspan, y0, options, varargin)
%     h = options.InitialStep(1);
%     K=options.K;
%     M=options.M;
%      F0=zeros(size(M,1));
%     F=@(t)F0;
%     if isfield( options,'F')
%         F=options.F;
%     end
%     maxit=12;
%     if isfield( options,'maxit')
%         maxit=options.maxit;
%     end
%     eta=0;
%     if isfield( options,'eta')
%         eta=options.eta;
%     end
%     nsteps = ceil ((tspan(2) - tspan(1)) / h);
%     ts = zeros(nsteps+1,1);
%     ys = zeros(nsteps+1,length(y0));
%     n=length(y0)/2;
%     t = tspan(1);
%     ts(1) = t;
%     ys(1,:) = y0';
%     S=(M-eta*(h^2)/2*K);% when the step size changes, this needs to change!
%     E=eye(n);
%     F0 =F(ts(1));
%     for step = 2:nsteps+1
%         if (ts(step-1) + h >tspan(2)), h=tspan(2)-ts(step-1); end
%         F1 =F(ts(step-1) + h);
%         y0 =ys(step-1,:)';
%         A = [zeros(n),eye(n);-(M\K),zeros(n)];
%         L0=[zeros(n,1);M\F0];
%         L1=[zeros(n,1);M\F1];
% %         y1 =(eye(length(y0))-h/2*(1+eta)*A+h^2/2*eta*A^2)\((eye(length(y0))+h/2*(1-eta)*A)*y0-h^2/2*eta*A*L1+h/2*L0+h/2*L1);
%         x0=ys(step-1,1:n)';
%         v0=ys(step-1,n+1:end)';
%          L0=[zeros(n,1);F0];
%         L1=[zeros(n,1);F1];
%        Al = [(M-(h^2)/2*eta*(K)),-h/2*(1+eta)*M;
%             h/2*(1+eta)*(K),(M-(h^2)/2*eta*(K))];
%         Ar = [M,h/2*(1-eta)*M;-h/2*(1-eta)*(K),M];
%         y1 = Al\(Ar*y0-(h^2)/2*eta*L1+h/2*(L0+L1));
% %         v1=v0+h/2*M\(F0+F1);
% %         x1=x0+h/2*(v0+v1);
% %         for it=1:maxit
% %             x1 =S\(M*((1+eta)*h/2*v1+(1-eta)*h/2*v0+x0)-eta*h^2/2*F1);
% %             v1 =S\(-(1+eta)*h/2*K*x1-(1-eta)*h/2*K*x0+M*v0+h/2*(F0+F1));
% %         end
% %         x1=(4*M^2+h^4*K^2)\(-2*(-2*M+h^2*K)*M*x0+4*h*M^2*v0);
% %         v1= (4*M^2+h^4*K^2)\(-4*h*M*K*x0-2*(-2*M+h^2*K)*M*v0);
%         ts(step) = ts(step-1) + h;
%         ys(step,:) = y1';
%         F0 =F1;
%     end
%     return;
% end
