% Classes: each folder corresponds to a class tree. The folders whose names
% start with the @ each hold the methods defined for the class. For
% instance, @gcellset_H20 holds the methods of the gcellset_H20 class.     
%
%   Folders:
%   FAESOR/classes/classbase        - Base class 
%   FAESOR/classes/data_colormap    - Mapping of values to colors. 
%   FAESOR/classes/elematset        - Element matrix class. 
%   FAESOR/classes/elevecset        - Element vector class. 
%   FAESOR/classes/feblock          - Group of classes to represent the physics 
%                                    of the model (construction of the various 
%                                    matrices and so on). 
%   FAESOR/classes/fenodeset        - Finite element node. 
%   FAESOR/classes/fenode_to_gcell_map  - Map from geometric cells to
%                                      nodes.
%   FAESOR/classes/field            - Field class represents functions on the mesh. 
%   FAESOR/classes/force_intensity  - Force-intensity class 
%   FAESOR/classes/gcellset         - Group of classes to represent various
%                                    finite element shapes (Geometric cells). 
%   FAESOR/classes/graphic_viewer   - Graphic viewer. 
%   FAESOR/classes/integration_rule - Group of classes for integration rules. 
%   FAESOR/classes/mater            - Group of classes to provide access to materials. 
%   FAESOR/classes/nodal_load       - Load at a node. 
%   FAESOR/classes/property         - Group of classes for material properties. 
%   FAESOR/classes/sysmat           - Group of classes for the system matrix.
%   FAESOR/classes/sysvec           - Global system vector. 
%
% Notes: 
% 1. One may find out which attributes are defined for a class by
%    typing the constructor on the command line.
%    For instance, executing `gcellset_H20' will print a list of attributes 
%    that can be obtained from the object and those that can be set.
% 2. One may inquire which methods are defined for a class
%    using the `methods' Matlab command. For instance, `methods field'.
% 3. All objects descended from classbase may be inspected 
%    with OBgui (a Matlab command in the util folder).
% 4. Constructors always take either zero or one argument.  For no
%    arguments, the default object is created.  For one argument, the argument
%    may be either an object of the same type, in which case a copy is
%    created; or, it may be a struct with one or more fields
%    representing the parameters to be passed to the constructor. 
%      For instance, these are equivalent calls to the
%    finite element node constructor: 
%       f=fenodeset(struct('id', 5,'xyz', [0, -.2])) 
%       Parameters.id=5; Parameters.xyz=[0, -.2]; f=fenode(Parameters)
% 5. Attributes may be retrieved from or changed in an object using the
%    get/set method pair. The get method may be used as get(obj). This form
%    returns a cell array of pairs of strings for each "gettable"
%    attribute: The first is the attribute 
%    name, the second is a brief description of the attribute. When the get
%    method is used with an argument, like this
%      get(obj,Attr_name)
%    where
%      obj       - object
%      Attr_name - attribute name
%    it returns the value of the named attribute.
%    The set method may be used as set(obj). This form
%    returns a cell array of pairs of strings for each "settable"
%    attribute: The first is the attribute name, the second is a brief
%    description of the attribute. When the set method is used with an
%    argument, like this 
%      obj =set(obj,Attr_name,val)
%    where
%      obj       - object
%      Attr_name - attribute name
%      val       - value to be assigned to the Attribute.
%    the modified object obj is returned (do not forget to assign it!).
%
