% Constructor of the element matrix set class.
%
% function self = elematset (varargin)
%
%  See discussion of constructors in <a href="matlab:helpwin 'FAESOR/classes/Contents'">classes/Contents</a>. 
%
% Parameters:
% eqnums= equation numbers, cell array of arrays of equation numbers
% mat = matrix, cell array of elementwise arrays
%
% Example:
% ems  = elematset(struct('mat',{Ke}, 'eqnums',{eqnums}));
% where
% conns = get(gcells, 'conn'); % connectivity
% Ke = cell(size(conns,1),1);
% eqnums = cell(size(conns,1),1);
% for i=1:size(conns,1)
%     eqnums{i} =gather(temp,conns(i,:),'eqnums');
%     Ke{i} =zeros(nfens);
% end
function self = elematset (varargin)
    class_name='elematset';
    parent=classbase;
    if (nargin == 0)
        self.eqnums_row = {};
        self.eqnums_col = {};
        self.mat = {};
        self = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            self = arg;
            return;
        else
            Parameters =varargin{1};
            if isfield(Parameters,'eqnums')
                self.eqnums_row = Parameters.eqnums;
                self.eqnums_col = {};
            else
                self.eqnums_row = Parameters.eqnums_row;
                self.eqnums_col = Parameters.eqnums_col;
            end
            self.mat = Parameters.mat;
            if (~ isempty(self.mat))
                [m,n] = size(self.mat{1});
                if isempty(self.eqnums_col)
                    gn=length(self.eqnums_row{1});
                    if (gn ~= n | gn ~= m | n ~= m )
                        error('Size mismatch!');
                    end
                else
                    gm=length(self.eqnums_row{1});
                    gn=length(self.eqnums_col{1});
                    if (gn ~= n | gm ~= m)
                        error('Size mismatch!');
                    end
                end
            end
            self = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end

