% Compute the stiffness matrices of the individual gcells.
% Return an array of them so they may be assembled.
%    Call as
% ems = stiffness(feb, geom, u1, u)
%     geom=reference geometry field
%     u1=displacement field in the *current* configuration
%     u=displacement field in the last known configuration
%    Returns an array of elemat objects that may be assembled
%    into the system stiffness matrix.
%
function ems = stiffness (self, geom, u)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells,'nfens');
    dim = get(geom,'dim');
    conns = get(gcells, 'conn'); % connectivity
    Kes= cell(length(gcells),1);
    eqnums = cell(length(gcells),1);
    Ke=diag(self.spring_constant);
    for i=1:length(gcells)
        eqnums{i} =gather(u,conns(i,:),'eqnums');
        Kes{i} = Ke;
    end
    ems  = elematset(struct('mat',{Kes}, 'eqnums',{eqnums}));
end
