% Compute element force vectors for to mass proportional terms (inertial
% force).
%
% function evs = inertial_force(self, geom, u, ems)
%
% Compute the element load vectors corresponding to nonzero essential boundary
% conditions (settlement of the supports).
% Return an array of them so they may be assembled.
%    Call as
% function evs = inertial_force(self, geom, u, ems)
% or
% function evs = inertial_force(self, geom, u)
%     geom=geometry field
%     u=displacement field
%
function evs = inertial_force(self, geom, u, ems)
    if (~exist('ems','var'))
        ems = mass (self, geom, u);
    end
    gcells = get(self.feblock_defor_ss,'gcells');
    % Pre-allocate the element matrices
     conns = get(gcells, 'conn'); % connectivity
    Fe = cell(size(conns,1),1);
    eqnums = cell(size(conns,1),1);
    mat=get(ems,'mat');
    % Now loop over all gcells in the block
    j=1;
    for i=1:length(gcells)
        conn = conns(i,:); % connectivity
        pu = gather(u, conn, 'values');
        if norm (pu) ~= 0
            Ke = mat{i}; % element stiffness matrix
            Fe{j} =  Ke*pu;
            eqnums{j} = gather(u, conn, 'eqnums');
            j=j+1;
        end
    end
    Fe=Fe(1:j-1);
    eqnums=eqnums(1:j-1);
    evs  = elevecset(struct('vec',{Fe}, 'eqnums',{eqnums}));
end