% Compute the element load vectors corresponding to nonzero essential boundary
% velocities.
% Return an array of them so they may be assembled.
%    Call as
% evs = nz_ebc_loads_damping(feb, geom, v)
%     geom=geometry field
%     v=velocity field
%
function evs = nz_ebc_loads_damping(self, geom, v)
    ems = damping(self, geom, v);
    gcells = get(self.feblock_defor_ss_sri,'gcells');
    % Pre-allocate the element matrices
    evs(1:length(gcells)) = deal(elevec);
    % Now loop over all gcells in the block
    for i=1:length(gcells)
        conn = get(gcells(i), 'conn'); % connectivity
        pu = gather(v, conn, 'prescribed_values');
        if norm (pu) ~= 0
            Ke = get(ems(i),'mat'); 
            evs(i) = set(evs(i), 'vec', -Ke*pu);
            evs(i) = set(evs(i), 'eqnums', gather(v, conn, 'eqnums'));
        end
    end
    return;
end
