% Compute the source-term load vectors of the individual gcells.
%
% function evs = source_loads(self, geom, temp)
%
% Return an array of them so they may be assembled.
%    Call as
%       evs = source_loads(feb, geom, temp)
%    where
%       geom=geometry field
%       temp=temperature field
%
function evs = phase_change_loads(self, geom, temp, gLdot,L)
    gcells = get(self.feblock_diffusion,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    % Pre-allocate the element matrices
    evs(1:ngcells) = deal(elevec);
    % Integration rule
    integration_rule = get(self.feblock_diffusion, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    % Material
    mat = get(self.feblock_diffusion, 'mater');
    kappa = get(get(mat,'property'),'thermal_conductivity');
    % Now loop over all gcells in the block
    for i=1:ngcells
        conn = get(gcells(i), 'conn'); % connectivity
        x = gather(geom, conn, 'values', 'noreshape');
        gLd = gather(gLdot, conn, 'values', 'noreshape');
        Fe = zeros(nfens,1); % element load vector
        % Loop over all integration points
        for j=1:npts_per_gcell
            Nder = bfundpar (gcells(i), pc(j,:));
            detJ = Jacobian_volume(gcells(i),pc(j,:),x);
            N = bfun(gcells(i), pc(j,:));
            Fe = Fe + N * ((-L*N'*gLd) * detJ * w(j));
        end
        evs(i) = set(evs(i), 'vec', Fe);
        evs(i) = set(evs(i), 'eqnums', ...
            gather(temp, conn, 'eqnums'));
    end
end

% function v = phase_change_source(gLn1,gLn,dt,L,NV)
%     v=0*gLn1;
%     for j=1:length(gLn1)
%         v(j) =-L*(gLn1(j)-gLn(j))/dt*NV(j,j);
%     end
% end
