% Evaluate the volume Jacobian.
%
% function Jac = Jacobian_volume(self, conn, N, J, x)
%
%   For the two-dimensional cell, the volume Jacobian is
%       (i) the product of the 2-D Jacobian and the other dimension (Units
%       of length);
%       or, when used as axially symmetric
%       (ii) the product of the 2-D Jacobian and the circumference of
%       the circle through the point pc 
% 
%   where
%      self=gcellset,
%      conn=connectivity of a single cell in which the Jacobian is to be evaluated
%      N=values of the basis functions, size(N) = [nbfuns,1]
%      J = Jacobian matrix
%      x=array of spatial coordinates of the nodes, size(x) = [nbfuns,dim]
%
function Jac = Jacobian_volume(self, conn, N, J, x)
    if self.axisymm
        xyz =N'*x;
        Jac = Jacobian_surface(self, conn, N, J, x)*2*pi*xyz(1);
    else
        Jac = Jacobian_surface(self, conn, N, J, x)*other_dimension(self, conn, N, x);
    end
end
