% Draw a graphic representation of an isosurface 
% in a three-manifold geometric cell.
%
% function draw_isosurface (self, gv, context)
%
%
% Input arguments
% self = self
% gv = graphic viewer
% context = struct
% with mandatory fields
%    x=reference geometry field
%    u=displacement field
% with optional fields
%    scalarfield =field with scalar vertex data,
%    isovalue = value of the isosurface
%    color = what color should the isosurface be?  Default: [1,1,1]/2;
%    nref = how refined should the parametric space of the geometric cell
%         be? Default: 2.
%
function   draw_isosurface(self, gv, context)
    if (isfield(context,'isovalue'))
        isovalue =context.isovalue;
    else
        isovalue =0;
    end
    if ((min(scalars)>isovalue) ||  (max(scalars)<isovalue))
        return
    end
    if (isfield(context,'color'))
        color =context.color;
    else
        color =[1,1,1]/2;
    end
    nref=2;
    if (isfield(context,'nref'))
        nref =context.nref;
    end
    
    xis =linspace(-1,+1,nref);
    [X,Y,Z] = ndgrid(xis,xis,xis);
    V=0*Z;
    for k=1:length(xis)
        for j=1:length(xis)
            for i=1:length(xis)
                N = bfun(self, [xis(i),xis(j),xis(k)]);
                V(i,j,k)=N'*scalars;
            end
        end
    end
    
    conn = get(self, 'conn'); % connectivity
    if (isempty(conn))
        return; % nothing to be done
    end
    x = gather(context.x, conn, 'values', 'noreshape'); % coordinates of nodes
    u = gather(context.u, conn, 'values', 'noreshape'); % coordinates of nodes
    xu=x+u;
    
    [f,v] = isosurface(X,Y,Z,V,isovalue);
    for i=1:size(v,1)
        N = bfun(self, v(i,:));
        v(i,:)=N'*xu;
    end
    facealpha = 1;
    if (isfield(context,'facealpha'))
        facealpha = context.facealpha;
    end
    patch('Faces',f,'Vertices',v,'FaceColor',color,'EdgeColor','none','FaceAlpha', facealpha);
end
