% Evaluate the derivatives of the basis function matrix.
%
% function val = bfundpar (self, param_coords)
%
% Returns an array of NFENS rows, and DIM columns, where
%    NFENS=number of nodes, and
%    DIM=number of spatial dimensions.
% Call as:
%    Nder = bfundpar(g, pc)
% where g=gcell
%       pc=parametric coordinates, -1 < pc(j) < 1, length(pc)=3.
% Column j holds derivatives of the basis functions with respect
% to the parametric coordinate j. Row i holds derivatives of the basis
% function i with respect to all the parametric coordinates in turn.
%
function N = bfundpar (self, param_coords)
    xi=param_coords(1);
    et=param_coords(2);
    N(1,:)=[1/256*(et-1)*(3*et-1)*(3*et+1)*(27*xi^2-18*xi-1),1/256*(-1-18*et+27*et^2)*(xi-1)*(3*xi-1)*(3*xi+1)];
    N(2,:)=[-9/256*(et-1)*(3*et-1)*(3*et+1)*(9*xi^2-3-2*xi),-9/256*(27*et^2-1-18*et)*(xi-1)*(3*xi-1)*(xi+1)];
    N(3,:)=[9/256*(et-1)*(3*et-1)*(3*et+1)*(-3+2*xi+9*xi^2),9/256*(27*et^2-1-18*et)*(xi-1)*(3*xi+1)*(xi+1)];
    N(4,:)=[-1/256*(et-1)*(3*et-1)*(3*et+1)*(27*xi^2-1+18*xi),-1/256*(27*et^2-1-18*et)*(3*xi-1)*(3*xi+1)*(xi+1)];
    N(5,:)=[-9/256*(et-1)*(3*et-1)*(et+1)*(27*xi^2-1-18*xi),-9/256*(9*et^2-3-2*et)*(xi-1)*(3*xi-1)*(3*xi+1)];
    N(6,:)=[81/256*(et-1)*(3*et-1)*(et+1)*(9*xi^2-3-2*xi),81/256*(-3-2*et+9*et^2)*(xi-1)*(3*xi-1)*(xi+1)];
    N(7,:)=[-81/256*(et-1)*(3*et-1)*(et+1)*(-3+2*xi+9*xi^2),-81/256*(-3-2*et+9*et^2)*(xi-1)*(3*xi+1)*(xi+1)];
    N(8,:)=[9/256*(et-1)*(3*et-1)*(et+1)*(27*xi^2+18*xi-1),9/256*(-3-2*et+9*et^2)*(3*xi-1)*(3*xi+1)*(xi+1)];
    N(9,:)=[9/256*(et-1)*(3*et+1)*(et+1)*(-1-18*xi+27*xi^2),9/256*(9*et^2-3+2*et)*(xi-1)*(3*xi-1)*(3*xi+1)];
    N(10,:)=[-81/256*(et-1)*(3*et+1)*(et+1)*(9*xi^2-2*xi-3),-81/256*(9*et^2-3+2*et)*(xi-1)*(3*xi-1)*(xi+1)];
    N(11,:)=[81/256*(et-1)*(3*et+1)*(et+1)*(2*xi+9*xi^2-3),81/256*(9*et^2+2*et-3)*(xi-1)*(3*xi+1)*(xi+1)];
    N(12,:)=[-9/256*(et-1)*(3*et+1)*(et+1)*(-1+27*xi^2+18*xi),-9/256*(9*et^2+2*et-3)*(3*xi-1)*(3*xi+1)*(xi+1)];
    N(13,:)=[-1/256*(3*et-1)*(3*et+1)*(et+1)*(-1+27*xi^2-18*xi),-1/256*(18*et+27*et^2-1)*(xi-1)*(3*xi-1)*(3*xi+1)];
    N(14,:)=[9/256*(3*et-1)*(3*et+1)*(et+1)*(9*xi^2-3-2*xi),9/256*(18*et+27*et^2-1)*(xi-1)*(3*xi-1)*(xi+1)];
    N(15,:)=[-9/256*(3*et-1)*(3*et+1)*(et+1)*(2*xi+9*xi^2-3),-9/256*(18*et-1+27*et^2)*(xi-1)*(3*xi+1)*(xi+1)];
    N(16,:)=[1/256*(3*et-1)*(3*et+1)*(et+1)*(27*xi^2-1+18*xi),1/256*(18*et-1+27*et^2)*(3*xi-1)*(3*xi+1)*(xi+1)];
    return;
end
