% Constructor of the  class that represents a two-node BEAM geometric cell.
% 
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing Parameters.
% Parameters: same as gcellset.
% and A = cross-sectional area of the rod
%     I1= moment of inertia of the cross-section, twisting about the beam axis 
%     I2, I3=moments of inertia, bending about the x2-axis (I2) or x3-axis (I3)
%     J= torsion constant, (to give torsion stiffness =G*J)
%     x1x2_vector= vector in the local x1,x2 plane. The direction of the
%       local x1 axis is from the first node to the second node. The third
%       basis vector of the local coordinate system is normalized cross
%       product of the first based vector with the x1x2_vector.
%
function retobj = gcellset_beam3 (varargin)
    class_name='gcellset_beam3';
    nfens=2;
    if (nargin == 0)
        self.nfens=nfens;
        self.conn=[];
        self.A = 0;
        self.I1 = 0;
        self.I2 = 0;
        self.I3 = 0;
        self.J = 0;
        self.x1x2_vector=[];
        parent=gcellset(self);
        retobj = class(self,class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            Parameters=varargin{1}; 
            self.nfens=nfens;
            self.conn=Parameters.conn;
            self.A = Parameters.A;
            if (length(self.A)==1)
                self.A=self.A+zeros(size(Parameters.conn,1),1);
            end
            self.I1 = Parameters.I1;
            if (length(self.I1)==1)
                self.I1=self.I1+zeros(size(Parameters.conn,1),1);
            end
            self.I2 = Parameters.I2;
            if (length(self.I2)==1)
                self.I2=self.I2+zeros(size(Parameters.conn,1),1);
            end
            self.I3 = Parameters.I3;
            if (length(self.I3)==1)
                self.I3=self.I3+zeros(size(Parameters.conn,1),1);
            end
            self.J = Parameters.J;
            if (length(self.J)==1)
                self.J=self.J+zeros(size(Parameters.conn,1),1);
            end
            self.x1x2_vector=reshape(Parameters.x1x2_vector,3,1);
            if (size(self.x1x2_vector,2)==1)
                self.x1x2_vector=self.x1x2_vector*ones(1,size(Parameters.conn,1));
            end
            parent=gcellset(self);
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end