% gcellset
%
%   A gcellset is an object for a set of geometric cells.  
%   The gcellset class is abstract (i.e. there is no point 
%   in making objects of this class), but all other gcellsets
%   (gcellset_H8 for hexahedra, ...) are descendants of this 
%   class. More precisely, they are descendents of the classes
%   gcellset_X_manifold, which endow the class gcellset with a
%   dimension (0 for a point, 1 for a curve, and so on).
% 
% -base class
%   @gcellset/gcellset - Constructor
%   @gcellset/bfun - Values of basis functionsValues of basis functions
%   @gcellset/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset/bfundsp - Derivatives of basis functions with respect to spatial
%                     (Cartesian) coordinates.
%   @gcellset/get - Get an attribute
%   @gcellset/set - Set an attribute
%   @gcellset/cat - Concatenate two sets of cells
%   @gcellset/count - Count the cells
%   @gcellset/subset - Extract a subset of the cells
%   @gcellset/draw - Draw the cell
%   @gcellset/draw_isosurface - Draw an isosurface
%   @gcellset/Jacobian_matrix - Compute the Jacobian matrix
%   @gcellset/in_parametric - Are given parametric coordinates inside the element parametric domain?
%   @gcellset/map2parametric - Map point to parametric coordinates 
% 
% Specializations to manifolds of various dimensions:
% 
% -zero-dimensional manifold (point)
%   @gcellset_0_manifold/gcellset_0_manifold - Constructor
%   @gcellset_0_manifold/other_dimension - Get the associated other dimension
%   @gcellset_0_manifold/Jacobian_mdim - Compute Jacobian, given m dimensions 
%   @gcellset_0_manifold/Jacobian_volume - Compute Jacobian, volume 
%   @gcellset_0_manifold/Jacobian_surface - Compute Jacobian, surface 
%   @gcellset_0_manifold/Jacobian_curve - Compute Jacobian, curve 
%   @gcellset_0_manifold/Jacobian - Jacobian appropriate for this manifold.
%   @gcellset_0_manifold/get - Get an attribute
% 
% -one-dimensional manifold (curve)
%   @gcellset_1_manifold/gcellset_1_manifold - constructor
%   @gcellset_1_manifold/other_dimension - Get the associated other dimension
%   @gcellset_1_manifold/Jacobian_mdim - Compute Jacobian, given m dimensions  
%   @gcellset_1_manifold/Jacobian_volume - Compute Jacobian, volume 
%   @gcellset_1_manifold/Jacobian_surface - Compute Jacobian, surface 
%   @gcellset_1_manifold/Jacobian_curve - Compute Jacobian, curve 
%   @gcellset_1_manifold/Jacobian - Jacobian appropriate for this manifold.
%   @gcellset_1_manifold/get - Get an attribute
%    
% -two-dimensional manifold (surface)
%   @gcellset_2_manifold/gcellset_2_manifold - Constructor
%   @gcellset_2_manifold/other_dimension - Get the associated other dimension
%   @gcellset_2_manifold/Jacobian_mdim - Compute Jacobian, given m dimensions  
%   @gcellset_2_manifold/Jacobian_volume - Compute Jacobian, volume 
%   @gcellset_2_manifold/Jacobian_surface - Compute Jacobian, Surface 
%   @gcellset_2_manifold/Jacobian - Jacobian appropriate for this manifold.
%   @gcellset_2_manifold/get - Get an attribute
%   @gcellset/draw - Draw the cell set
%   
% -three-dimensional manifold (solid)
%   @gcellset_3_manifold/gcellset_3_manifold - constructor
%   @gcellset_3_manifold/Jacobian_mdim -  Compute Jacobian, given m dimensions  
%   @gcellset_3_manifold/Jacobian_volume - Compute Jacobian, volume 
%   @gcellset_3_manifold/Jacobian - Jacobian appropriate for this manifold.
%   @gcellset_3_manifold/get - Get an attribute
%   @gcellset/draw - Draw the cell set
%   @gcellset/draw_isosurface - Draw the isosurface within the cell set
% 
% Specialized classes:
%  All of the classes must supply the methods
%   Constructor, bfun, bfundpar, get, draw
% 
% -one-node point P1
%   @gcellset_P1/gcellset_P1 - Constructor
%   @gcellset_P1/bfun - Values of basis functions
%   @gcellset_P1/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_P1/get - Get an attribute
%   @gcellset_P1/draw - Draw the cell
% 
% -two-node segment L2
%   @gcellset_L2/gcellset_L2 - Constructor
%   @gcellset_L2/bfun - Values of basis functions
%   @gcellset_L2/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_L2/get - Gets an attribute
%   @gcellset_L2/draw - Draw the cell
% 
% -three-node segment L3
%   @gcellset_L3/gcellset_L3 - Constructor
%   @gcellset_L3/bfun - Values of basis functions
%   @gcellset_L3/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_L3/get - Gets an attribute
%   @gcellset_L3/draw - Draw the cell
% 
% -four-node segment L4
%   @gcellset_L4/gcellset_L4 - Constructor
%   @gcellset_L4/bfun - Values of basis functions
%   @gcellset_L4/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_L4/get - Gets an attribute
%   @gcellset_L4/draw - Draw the cell
% 
% -three-node triangle T3
%   @gcellset_T3/gcellset_T3 - Constructor
%   @gcellset_T3/bfun - Values of basis functions
%   @gcellset_T3/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_T3/get - Get an attribute
%   @gcellset_T3/draw - Draw the cell
% 
% -six-node triangle T6
%   @gcellset_T6/gcellset_T6 - Constructor
%   @gcellset_T6/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_T6/bfun - Values of basis functions
%   @gcellset_T6/get - Gets an attribute
%   @gcellset_T6/draw - Draw the cell
%   @gcellset_T6/in_parametric - Are given parametric coordinates inside the element parametric domain?
% 
% -four-node quadrilateral Q4
%   @gcellset_Q4/gcellset_Q4 - Constructor
%   @gcellset_Q4/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_Q4/bfun - Values of basis functions
%   @gcellset_Q4/get - Get an attribute
%   @gcellset_Q4/draw - Draw the cell
% 
% -eight-node quadrilateral Q8
%   @gcellset_Q8/gcellset_Q8 -  constructor
%   @gcellset_Q8/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_Q8/bfun - Values of basis functions
%   @gcellset_Q8/get - Gets an attribute
%   @gcellset_Q8/draw - Draw the cell
% 
% -9-node quadrilateral Q9
%   @gcellset_Q9/gcellset_Q9 -  constructor
%   @gcellset_Q9/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_Q9/bfun - Values of basis functions
%   @gcellset_Q9/get - Gets an attribute
%   @gcellset_Q9/draw - Draw the cell
% 
% -16-node quadrilateral Q16
%   @gcellset_Q16/gcellset_Q16 -  constructor
%   @gcellset_Q16/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_Q16/bfun - Values of basis functions
%   @gcellset_Q16/get - Gets an attribute
%   @gcellset_Q16/draw - Draw the cell
% 
%-four-node tetrahedron T4
%   @gcellset_T4/gcellset_T4 - Constructor
%   @gcellset_T4/bfun - Values of basis functions
%   @gcellset_T4/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_T4/get - Gets an attribute
%   @gcellset_T4/draw - Draw the cell
% 
% -10-node tetrahedron T10
%   @gcellset_T10/gcellset_T10 - Constructor
%   @gcellset_T10/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_T10/bfun - Values of basis functions
%   @gcellset_T10/get - Get an attribute
%   @gcellset_T10/draw - Draw the cell
%   @gcellset_T10/in_parametric - Are given parametric coordinates inside the element parametric domain?
% 
% -eight-node hexahedron H8
%   @gcellset_H8/gcellset_H8 -  constructor
%   @gcellset_H8/bfun - Values of basis functions
%   @gcellset_H8/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_H8/get - Get an attribute
%   @gcellset_H8/draw - Draw the cell
% 
% -20-node hexahedron H20
%   @gcellset_H20/gcellset_H20 - Constructor
%   @gcellset_H20/bfun - Values of basis functions
%   @gcellset_H20/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_H20/get - Got an attribute
%   @gcellset_H20/draw - Draw the cell
% 
% -27-node hexahedron H27
%   @gcellset_H27/gcellset_H27 - Constructor
%   @gcellset_H27/bfun - Values of basis functions
%   @gcellset_H27/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_H27/get - Got an attribute
%   @gcellset_H27/draw - Draw the cell
% 
% -64-node hexahedron H64
%   @gcellset_H64/gcellset_H64 - Constructor
%   @gcellset_H64/bfun - Values of basis functions
%   @gcellset_H64/bfundpar - Derivatives of basis functions with the respect to 
%                     parametric coordinates.
%   @gcellset_H64/get - Got an attribute
%   @gcellset_H64/draw - Draw the cell
%


