% Constructor of a quadrature rule for tetrahedra.
%
% function retobj = tet_rule (varargin)
%
% Parameters=structure with the mandatory fields
%      npts=number of points (1-- one-point rule, 4 -- four-point rule).
% 
% For historical reasons one may pass npts as a number and get an npts=1 rule.
% 
%   Call as:
%      ir = tet_rule(npts);
%   or
%      ir = tet_rule(struct('npts',1 ));
%
function retobj = tet_rule (varargin)
class_name='tet_rule';
parent=classbase;
if (nargin == 1)
    arg = varargin{1};
    if strcmp(class(arg),class_name) % copy constructor.
        retobj = arg;
        return;
    else
        if  ~(strcmp(class(varargin{1}),'double'))
            Parameters =varargin{1};
            self.npts = Parameters.npts;
        else
            self.npts = varargin{1};
        end
        switch self.npts
            case 1
                self.param_coords = ...
                    [0.25,0.25,0.25];
                self.weights = [1/6];
            case 4
                self.param_coords = ...
                    [[0.13819660,0.13819660,0.13819660];...
                    [0.58541020,0.13819660,0.13819660];...
                    [0.13819660,0.58541020,0.13819660];...
                    [0.13819660,0.13819660,0.58541020]];
                self.weights = [ 0.041666666666666666667,  0.041666666666666666667,  0.041666666666666666667,  0.041666666666666666667];
            otherwise
                error('Unknown number of points!');
        end
        retobj = class(self,class_name,parent);
        return;
    end
end
