% Calculate vector of thermal stress components.
%
% function v = thermal_stress(self,context)
%
%   Call as:
%     v = thermal_stress(m,context)
%  where
%     m=material
%     context=structure; see the update() method
%
function v = thermal_stress(self,context)
    if (isfield( context,'dT' ))
        E = get(self.property,'E', context);;
        nu = get(self.property,'nu', context);;
        lambda = E * nu / (1 + nu) / (1 - 2*(nu));          % Lame constant #1
        mu     = E / (2 * (1 + nu));                        % shear modulus
        kappa  = E / 3 / (1 - 2*nu);                        % bulk modulus
        mI = diag([1 1 1 0.5 0.5 0.5]);
        m1     = [1 1 1 0 0 0]';
        D = lambda * m1 * m1' + 2 * mu * mI;
        alphas = get(self.property,'alphas');
        v =-D*context.dT*[alphas.*ones(3, 1); zeros(3, 1)];
    else
        v= zeros(6, 1);
    end
    return;
end
