% Constructor of linearly elastic,  Inhomogeneous isotropic material.
%
% function retobj = property_linel_iso_inhomog(varargin)
%
% This class represents material properties of deformable linearly elastic 
% isotropic inhomogeneous materials.
% See discussion of constructors in <a href="matlab:helpwin 'FAESOR/classes/Contents'">classes/Contents</a>. 
% Parameters:
% required fields
%     E=Young's modulus, supplied either as a number or as a handle to a
%     function that returns the value of the Young's modulus as a function
%     of physical location, E=f(xyz).
%     nu=Poisson ratio, supplied either as a number or as a handle to a
%     function that returns the value of the Poisson ratio as a function
%     of physical location, nu=g(xyz).
% optional fields
%     alpha = coefficient of thermal expansion, default 0.0
%
function retobj = property_linel_iso_inhomog(varargin)
    class_name='property_linel_iso_inhomog';
    if (nargin == 0)
        parent=property;
        self.E = 1.0;
        self.nu = 0.0;
        self.alpha = 0.0;
        retobj = class(self,class_name, parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            Parameters =varargin{1};
            parent=property(Parameters);
            self.E = Parameters.E;
            self.nu = 0;
            if isfield(Parameters,'nu')
                self.nu = Parameters.nu;
            end
            self.alpha = 0.0;
            if isfield(Parameters,'alpha')
                self.alpha= Parameters.alpha;
            end
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end
