% Constructor.
%
% function retobj = property_linviscel_iso(varargin)

% This class represents material properties of viscous (Newtonian) fluid materials.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing parameters.
% Parameters:
% required fields
%     as for property_linel_iso
%     eta=shear viscosity
% optional fields
%     alpha = coefficient of thermal expansion
%
function retobj = property_linviscel_iso(varargin)
    class_name='property_linviscel_iso';
    if (nargin == 0)
        parent=property_linel_iso;
        self.eta = 0.0;
        self.D_visc =[];
        retobj = class(self,class_name, parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            Parameters =varargin{1};
            parent=property_linel_iso(Parameters);
            self.eta = 0;
            self.D_visc =[];
            if isfield(Parameters,'eta')
                self.eta = Parameters.eta;
                if (self.eta < 0)
                    error('Negative viscosity!');
                end
            end
            % precompute
            self.D_visc =  2 * self.eta * [2/3*[2 -1 -1; -1 2 -1; -1 -1 2] zeros(3,3); zeros(3,3) eye(3,3) ];
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end
