% Hemisphere in water, planar wave directed at an angle to the X. axis
% Structured grid
function savefile=water_hemis_td_struc
    frequency=10000; angle=0;
    %     pressuremag*R/(rhow*cw^2)./(2*pi*frequency/cw*R)*3/(2*rho/rhow+1);
    R=5.0;% radius of the sphere, millimeters
    nR=3;
    Ro=nR*R; % width of the box, millimeters
    nperR=6;%
    nlayers=nperR;
    rho=1e-9;% mass density
    c = 1.4491e+006;% millimeters per second
    P_amplitude=10^9*1e-6*1e-6;% MPa
    rhos=2.5e-9;% mass density
    %     rhos=rho;% mass density
    dt=1/frequency/20;
    tshift=0;
    tfinal=4*(1/frequency);
    graphics= true;% plot the solution as it is computed?
    saveimg= ~true;
    savevariables= ~true;
    tol=R/10000;
    
    bulk= c^2*rho;
    nsteps=round(tfinal/dt)+1;
    omega=2*pi*frequency;
    wavenumber=omega/c;
    front_normal=[cos(pi/180*angle),sin(pi/180*angle),0]';
    wavevector=wavenumber*front_normal;
    uincA=P_amplitude/rho/c/omega;
    postfilename=[mfilename  '-nR' num2str(nR)  '-nperR' num2str(nperR)  '-a' num2str(angle) '-f' num2str(frequency)];
    savefile=[postfilename  '.mat'];
    
    % % %     % Mesh
    
    [fens,gcells]=H8_sphere_n(R,nperR);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [-1,0,0], [0,0,0], @(c)c([1, 4, 3, 2, 5, 8, 7, 6]));
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tol);
    gcells=cat(gcells1,gcells2);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [0,-1,0], [0,0,0], @(c)c([1, 4, 3, 2, 5, 8, 7, 6]));
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tol);
    gcells=cat(gcells1,gcells2);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [0,0,-1], [0,0,0], @(c)c([1, 4, 3, 2, 5, 8, 7, 6]));
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tol);
    gcells=cat(gcells1,gcells2);
    
    clear options
    options. box=[-inf,inf,-inf,inf,0,inf];
    options. inflate=(Ro-R)/nlayers/100;
    Solidl=gcell_select(fens, gcells, options);
    
    feb = feblock (struct ('mater',[], 'gcells',subset(gcells,Solidl),...
        'integration_rule', gauss_rule (3,2)));
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    V=measure(feb,geom,@(x)(1))
    S=measure(feb,geom,@(x)(x))
    CG=S/V
    I=measure(feb,geom,@(x)(norm(x-CG)^2*eye(3)-(x-CG)'*(x-CG)))
    %     I=measure(feb,geom,@(x)(skewmat(x-CG)'*skewmat(x-CG))) 
    mass=V*rhos;
    Inertia=I*rhos;
    
    bg=mesh_bdry(gcells);
    fens1=fens; gcells1=subset(gcells,setdiff(1: count(gcells),Solidl));
    clear gcells
    %     gv=drawmesh({fens,bg,'facecolor','white'},'gcells','facecolor','white','facealpha',0.1)
    %     
    [fens,gcells] = Q4_extrude(fens,bg,nlayers,@(xyz, layer)(R+layer/nlayers*(Ro-R))*xyz/norm(xyz));
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tol);
    gcells=cat(gcells1,gcells2);
    %         gv=drawmesh({fens,bg,'facecolor','white'},'gcells','facecolor','white','facealpha',0.1)
    %         
    connected = find_unconn_fens(fens, gcells);
    [fens, new_numbering] =compact_fens(fens, connected);
    gcells = renumber_gcell_conn(gcells, new_numbering);
    
    bdry_gcells = mesh_bdry(gcells, struct('other_dimension', 1));
    clear options
    options. distance=R;
    options. inflate=(Ro-R)/nlayers/10;
    Intl=gcell_select(fens, bdry_gcells, options);
    clear options
    Extl  =setdiff(1:count(bdry_gcells),Intl);
    target_gcells=subset(bdry_gcells,Intl);
    
    if (graphics )
        gv=drawmesh({fens,target_gcells},'gcells','facecolor','red')
        gv=drawmesh({fens,subset(bdry_gcells,Extl)},'gv',gv,'gcells','facecolor','y','facealpha',0.3)
        set_graphics_defaults
        labels('x','y','z')
    end
    
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    
    
    disp( ['Mesh size: final ' num2str(count(fens))])
    
    
    % % %
    
    prop=property_viscous_fluid(struct('bulk',bulk,'rho',rho));
    mater=mater_defor_ss_linviscel_triax (struct('property',prop));
    feb = feblock_acoustics (struct (...
        'mater',mater,'gcells',gcells,...
        'integration_rule',gauss_rule(3,2)));
    function n= surface_normal(x,tangent)
        n= cross(tangent(:,1),tangent(:,2));
        n=n/norm(n);
    end
    sfeb = feblock_acoustics (struct (...
        'mater',mater,'gcells',target_gcells,...
        'integration_rule',gauss_rule(2,2),'N',@surface_normal));
    abcfeb = feblock_acoustics (struct (...
        'mater',mater,'gcells',subset(bdry_gcells,Extl),...
        'integration_rule',gauss_rule(2,2)));
    
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    P = field(struct ('name',['P'], 'dim', 1,'nfens',get(geom,'nfens')));
    P = numbereqns (P);
    tcn = connected_nodes(target_gcells);
    on = setdiff((1:get(geom,'nfens')),tcn);
    permutation=zeros(get(geom,'nfens'),1);
    permutation(tcn)=(1:length(tcn))';
    permutation(on)=(length(tcn)+1:get(P, 'neqns'))';
    P = numbereqns (P,permutation);
    
    S = start (sparse_sysmat, get(P, 'neqns'));
    S = assemble (S, acoustic_stiffness(feb, geom, P));
    mS =get(S,'mat'); clear S
    C = start (sparse_sysmat, get(P, 'neqns'));
    C = assemble (C, acoustic_mass(feb, geom, P));
    mC =get(C,'mat'); clear C
    D = start (sparse_sysmat, get(P, 'neqns'));
    D = assemble (D, surface_acoustic_ABC(abcfeb, geom, P));
    mD =get(D,'mat'); clear D
    
    ForceF = field(struct ('name',['ForceF'], 'dim', 1,'nfens',3));
    ForceF = numbereqns (ForceF);
    
    TorqueF = field(struct ('name',['TorqueF'], 'dim', 1,'nfens',3));
    TorqueF = numbereqns (TorqueF);
    
    GF = start (sparse_sysmat, get(ForceF, 'neqns'), get(P, 'neqns'));
    GF = assemble(GF, pressure_to_resultant_force (sfeb, geom, P, ForceF));
    mGF =get(GF,'mat'); clear GF
    GT = start (sparse_sysmat, get(TorqueF, 'neqns'), get(P, 'neqns'));
    GT = assemble(GT, pressure_to_resultant_torque(sfeb, geom, P, TorqueF, CG));
    mGT =get(GT,'mat'); clear GT
    mH = mGF'*(rho/mass)*mGF+mGT'*(sparse(rho*inv(Inertia)))*mGT;
    
    mCtild=mC+mH;
    clear mH
    
    % Solve
    P0 =0*P; % initially all pressure is zero
    clear P
    vP0= gather_sysvec(P0);
    vP1=0*vP0;
    vQ0= 0*vP0;
    vQ1=0*vQ0;
    t=0;
    P1 =P0;
    tTa1=[0;0;0];
    tAa1=[0;0;0];
    tTa0=tTa1; 
    tAa0=tAa1; 
    
    fiabc= force_intensity(struct('magn',@abc_pressure_gradient));
    
    pinc =0*P0; % initially all pressure is zero
    pincdd =0*P0; % initially all pressure acceleration is zero
    xyz =get(geom,'values');
    allnl=(1:count(fens));
    function recalculate_incident(t)
        arg=(-xyz*wavevector+omega*(t+tshift));% wave along the x-axis
        vpinc=P_amplitude*sin(arg);
        pinc= scatter(pinc,allnl,vpinc);
        vpincdd=-omega^2*vpinc;
        pincdd= scatter(pincdd,allnl,vpincdd);
        clear vpinc vpincdd
    end
    recalculate_incident(0);
    L0=-mS*gather_sysvec(pincdd)-mCtild*gather_sysvec(pinc);
    F = start (sysvec, get(P1, 'neqns'));
    F = assemble (F, pressure_flux_loads (abcfeb, geom, P1, fiabc));
    La0 =get(F, 'vec');
    tic; disp([' Factorize mA'  ])
    mA = (2/dt)*mS +mD +(dt/2)*mCtild;
    disp(['    nnz mA='  num2str(nnz(mA))])
%     mA = (mA+mA')/2;
%     mA = spdiags(mA,0:-1:-size(mA,1));
    %     [D,dD,prm] = ldl(D,'vector');
    [mA,status,prm] = chol(mA,'lower','vector');
    if ( status ~= 0 ) error,end
    mAt= mA';
    disp(['    Factorized nnz mA='  num2str(nnz(mA))])
    disp(['      Done ' num2str(toc) ])
    
    if ( graphics )
        clear options
        options. box=[-inf,inf,0,inf,-inf,inf];
        options. inflate=(Ro-R)/nlayers/100;
        Halfl=gcell_select(fens, gcells, options);
        hbg = mesh_bdry(subset(gcells,Halfl), struct('other_dimension', 1));
        bfeb = feblock (struct ('mater',[], 'gcells',hbg,...
            'integration_rule', gauss_rule (2,2)));
        gv=graphic_viewer;
    end
    
    tTv=zeros(3,round(tfinal/dt)+1);
    tTu=tTv;tAv=tTv;tAu=tTv;    incTu=tTv;
    t=0;
    incTu(:,1)=-uincA*sin((-CG*wavevector+omega*(t+tshift)))*front_normal;
    step =0; snap=0;
    while t <=tfinal
        step = step  +1;
        tic; disp([' Time ' num2str(t) ' (' num2str(step) '/' num2str(round(tfinal/dt)+1) ')'])
        if graphics
            Camera =[-135.0272 -173.7116  128.3379    1.9441    4.7929   -1.5659         0         0    1.0000    5.2850];
            wv = get(P0,'values');%pinc+
            dcm=data_colormap(struct ('range',frequency/200000*P_amplitude*[-1,1], 'colormap',bwr));
            colors=map_data(dcm, wv);
            colorfield = field(struct ('name',['cf'], 'dim', 3, 'data',colors));
            gv=reset (gv,[]);
            camset(gv,Camera);
            draw(bfeb,gv, struct ('x', geom,'u',0*geom,'colorfield',colorfield,'edgecolor',[1,1,1]/2));
            draw_axes (gv,struct('length',2));
            for  isovalue=linspace(min(get(dcm, 'range')),max(get(dcm, 'range')),20)
                draw_isosurface(bfeb,gv, struct ('x', geom,'u',0*geom,'scalarfield',P0,'isovalue',isovalue,'color',[0,0,0]));
            end
               set_graphics_defaults
            axis off ; %   labels('x','y','z')
            pause(0.0055);
            if saveimg
                saveas(gcf, [mfilename '-' 'p'  '-i' n2s0p(snap) '.png'], 'png');
                snap= snap+1;
            end
        end
        t=t+dt;
        recalculate_incident(t);
        L1=-mS*gather_sysvec(pincdd)-mCtild*gather_sysvec(pinc);
        crhs=(2/dt)*(mS*vQ0)-mD*vQ0-mCtild*(2*vP0+(dt/2)*vQ0)+L0+L1+La0;
        F = start (sysvec, get(P1, 'neqns'));
        F = assemble (F, pressure_flux_loads (abcfeb, geom, P1, fiabc));
        La1 =get(F, 'vec');
        rhs=crhs+La1;
        vQ1(prm) = mAt\(mA\rhs(prm));
        vP1 = vP0 + (dt/2)*(vQ0+vQ1);
        P1 = scatter_sysvec(P1, vP1);
        vp1=gather_sysvec(pinc+P1);
        Fresultant=mGF*vp1;
        Tresultant=mGT*vp1;
        %         [Fresultant,Tresultant] 
        tTa1=Fresultant/mass; tAa1=Inertia\Tresultant;
        % Reset for the next time step
        vP0 = vP1;
        vQ0 = vQ1;
        P0 = P1;
        L0=L1;
        La0=La1;
        tTv(:,step+1)=tTv(:,step)+dt/2*(tTa0+tTa1);        
        tTu(:,step+1)=tTu(:,step)+dt/2*(tTv(:,step)+tTv(:,step+1));
        tAv(:,step+1)=tAv(:,step)+dt/2*(tAa0+tAa1);       
        tAu(:,step+1)=tAu(:,step)+dt/2*(tAv(:,step)+tAv(:,step+1));
        incTu(:,step+1)=-uincA*cos((-CG*wavevector+omega*(t+tshift)))*front_normal;
        tTa0=tTa1;
        tAa0=tAa1; 
    end% time integration loop
    tTu=tTu (:,1:step);
    tAu=tAu (:,1:step);
    incTu=incTu (:,1:step);
    clear mS mC mD mA mAt
    if ( savevariables )
        save (savefile);
    end
    
    uamplHW=P_amplitude/(rho*c^2)./(omega/c)*3/(2*rhos/rho+1);
    t=linspace(0,size(tTu,2)*dt,size(tTu,2));
    uxa=amplitude(t,remove_bias(t,tTu(1,:)));
    disp( ['Normalized Amplitude of the x-Displ.  of the CG=' num2str(uxa/uamplHW)])
    figure;
    hold on
    plot(t,remove_bias(t,tTu(1,:))/uamplHW,'kx-','linewidth',2)
    %     plot(t,remove_bias(t,tTu(2,:))/uamplHW,'gx--','linewidth',2)
    %     plot(t,remove_bias(t,tTu(3,:))/uamplHW,'bx:','linewidth',2) 
    grid on
    xlabel(' Time'); ylabel('Normalized x-Displ. of the CG'); set_graphics_defaults
    figure;
    hold on
    plot(t,tTu(1,:),'kx-','linewidth',2)
    %     plot(t,tTu(2,:),'gx--','linewidth',2)
    %     plot(t,tTu(3,:),'bx:','linewidth',2)
    grid on
    xlabel(' Time'); ylabel('x-Displacement of the CG'); set_graphics_defaults
    figure
    hold on
    %     plot(t,tAu(1,:),'rx-','linewidth',2)
    plot(t,tAu(2,:),'kx--','linewidth',2)
    %     plot(t,tAu(3,:),'bs:','linewidth',2)
    grid on
    xlabel(' Time'); ylabel('y-Rotation about the CG'); set_graphics_defaults
    figure;
    hold on
    %     plot(t,remove_bias(t,tAu(1,:))*R/uxa,'rx-')
    plot(t,remove_bias(t,tAu(2,:))*R/uxa,'kx--','linewidth',2)
    %     plot(t,remove_bias(t,tAu(3,:))*R/uamplHW,'bx:')
    grid on
    xlabel(' Time'); ylabel('Normalized z-Displ. Amplitude'); set_graphics_defaults
    rya=amplitude(t,remove_bias(t,tAu(2,:)));
    disp( ['Amplitude of the y-Rot. about the CG=' num2str(rya)])
    disp( ['Normalized z-Displ. Amplitude=' num2str(rya*R/uxa)])
    
    function val=target_pressure_gradient(x,J)
        n=cross(J(:,1),J(:,2)); n=n/norm(n);
        val=-rho*dot(cross(tAa1,x-CG)+tTa1',n);
    end
    function val=abc_pressure_gradient(x,J)
        n=cross(J(:,1),J(:,2)); n=n/norm(n);
        arg=(-x*wavevector+omega*(t+tshift));
        val=P_amplitude*cos(arg)*(-dot(n,wavevector));
    end
    
    function p= find_peaks(t,y)
        p=[];
        dy=diff(y);
        for j3=1:length(dy)-1
            if (dy(j3)*dy(j3+1)<0)
                p(end+1)=y(j3+1);
            end
        end 
    end
    function A= amplitude(t,y)
        p= find_peaks(t,y) ;
        A=mean(abs(p)) ;
    end
end