
%%  Timoshenko-Gere frame buckling
% *Under development*

% Parameters:
E=7.2e6;%N/cm^2
nu=0.;
A=6;%cm^2
I=2;%cm^4 
L=120;% cross-sectional dimensions and length of each leg
magn=+1;
neigvs=4;


% Mesh
n=16;
Parameters=struct ('A',A,'I2',I,'I3',I,'J',2*I,...
    'x1x2_vector',[0 0 1], 'label',1);
[fens1,gcells1] = Beam_member([[0 L 0];[L L 0]],n,@gcellset_beam3,Parameters);
Parameters=struct ('A',A,'I2',I,'I3',I,'J',2*I,...
    'x1x2_vector',[0 0 1], 'label',2);
[fens2,gcells2] = Beam_member([[L L 0];[L 0 0]],n,@gcellset_beam3,Parameters);

[fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens2, gcells2, 0);
gcells= cat(gcells1,gcells2);

[node1, node2]= Beam_join(fens,gcells, 1, 2, L/1000);
link.master=node1;
link.slave=node2;
link.component= [1,2,3]; % spherical joint

prop = property_linel_iso (struct('E',E,'nu',nu));
mater = mater_defor_ss_linel_triax (struct('property',prop));
% Finite element block
feb = feblock_defor_ss_beam3(struct ('mater',mater, 'gcells',gcells));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
ur  = field(struct ('name',['ur'], 'dim', 6, 'data', zeros(get(geom,'nfens'),6)));

% Apply EBC's
% First constrain everything to the xy plane
for ebc_comp=[3,4,5];
    ebc_fenids=1: count(fens);
    ebc_prescribed=[1];
    ebc_val=ebc_fenids*0;
    ur  = set_ebc(ur, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
end
ebc_fenids=fenode_select(fens, struct('box', update_box([],[0 L 0])));
ebc_prescribed=[1];
ebc_comp=[];% clamped
ebc_val=ebc_fenids*0;
ur  = set_ebc(ur, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ebc_fenids=fenode_select(fens, struct('box', update_box([],[L 0 0])));
ebc_prescribed=[1];
ebc_comp=[1,2,3,5];% cylindrical joint
ebc_val=0;
ur  = set_ebc(ur, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ur  = apply_ebc (ur);

% Number equations
ur  = numbereqns (ur, {link});
neqns=get(ur, 'neqns');

% Assemble the system matrix
K = start (sparse_sysmat, neqns);
K = assemble (K, stiffness(feb, geom, ur));
% Load
F = sysvec;
F = start (F, neqns);
evs = loads(nodal_load(struct ('id',fenode_select(fens, struct('box', update_box([],[L L 0]))),'dir',[1],'magn',[-magn])), ur);
F = assemble (F, evs);
% Solve
ur = scatter_sysvec(ur, K\F);
% get(ur,'values')


% Plot
gv=graphic_viewer;
gv=reset (gv,[]);
scale=200000;
u=slice(ur,(1:3),'u');
rot=slice(ur,(4:6),'rot');
draw(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'facecolor','none'));
draw(feb, gv, struct ('x', geom, 'u', scale*u, 'rot', scale*rot, 'facecolor','none'));
draw_local_coordinates(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'length',25));

xlabel('X');
ylabel('Y');
zlabel('Z');
hold on

draw(fens,gv, struct ('x', geom, 'u', 0*u, 'color','blue','offset',0.35));
draw_axes(gv, struct([]));

Kg = start (sparse_sysmat, neqns);
Kg = assemble (Kg, stiffness_geo(feb, geom, ur));

options.tol =1e-26;
options.maxit = 5000;
options.disp = 0;
[W,Omega]=eigs(-(get(Kg,'mat')+get(Kg,'mat')')/2,(get(K,'mat')+get(K,'mat')')/2,...
    neigvs,'lm', options);
% [Omegas,ix]=sort(1./abs(diag(Omega))) ;
% Omegas=somel(1./diag(Omega),ix);
Omegas=1./diag(Omega)
%
for i=1:4
    disp(['  Eigenvector ' num2str(i) ' eigenvalue ' num2str(Omegas(i)) ]);
end



scale=150;
w=clone(ur,'w'); % make a copy of u
for i=1:4
    disp(['  Eigenvector ' num2str(i) ' eigenvalue ' num2str(Omegas(i)) ]);
    ur = scatter_sysvec(w, W(:,i));
    u=slice(ur,(1:3),'u');
    rot=slice(ur,(4:6),'rot');
    wv = get(u,'values');
    wmag = sqrt(wv(:,1).^2+wv(:,2).^2+wv(:,3).^2);
    dcm=data_colormap(struct ('range',[min(wmag),max(wmag)], 'colormap',jet));
    colors=map_data(dcm, wmag);
    colorfield = field(struct ('name',['cf'], 'dim', 3, 'data',colors));
    gv=graphic_viewer;
    gv=reset (gv,[]);
    gv=reset (gv,[]);
    draw(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'facecolor','none'));
    draw(feb, gv, struct ('x', geom, 'u', scale*u, 'rot', scale*rot,'colorfield',colorfield));
    draw_axes(gv, struct([]));
    pause(2); % next eigenvector
end


