function  cyl_aug_nice
    disp('Cylinder squeezed between two flat rigid surfaces');

    c =clock; disp(['Started ' num2str(c(4)) ':' num2str(c(5)) ':' num2str(c(6)) ' '])
    % Parameters:
    E=1;
    nu= 0.48;
    L= 300;
    R=200;
    nsteps = 4;
    target_travel =R/2;
    travel = 0;
    nedges =6;
    penalty = 100*E;

    function  gap = get_gap(surface_data,x)
        if (x(3)>0)
            gap =R- travel-x(3);
        else
            gap =R- travel+x(3);
        end
        if (gap>0), gap = 0; end
    end
    function normal = get_normal(surface_data,x)
        if (x(3)>0)
            normal = [0, 0,-1];
        else
            normal = [0, 0, +1];
        end
    end

    % Mesh
        [fens,gcells] = t4cylinderdel(L,R,nedges,nedges);
%     [fens,gcells] = q4circle(R, 2, 1.0);
%     fens2 = transform_apply(fens,@(x,d)([-x(2),x(1)]),  0);
%     [fens,gcells,gcells2] = merge_meshes(fens, gcells, fens2, gcells, R/1000);
%     gcells = cat(gcells,gcells2);
%     fens2 = transform_apply(fens,@(x,d)([-x(1),-x(2)]),  0);
%     [fens,gcells,gcells2] = merge_meshes(fens, gcells, fens2, gcells, R/1000);
%     gcells = cat(gcells,gcells2);
%     [fens,gcells] = extrudeq4(fens,gcells,nedges,@(x,k)([x(1),x(2),k*L/nedges]));
%     fens = transform_apply(fens,@(x,d)([x(3),x(2),-x(1)]),  0);

    bdry_gcells = mesh_bdry(gcells,  []);
    topfacelist =gcell_select(fens,bdry_gcells,struct ('box',[0, 0 -R R -R R],'inflate',L/1000));
    bottomfacelist =gcell_select(fens,bdry_gcells,struct ('box',[L L -R R -R R],'inflate',L/1000));
    cylfacelist =setdiff((1:length(bdry_gcells)),union(topfacelist,bottomfacelist));
    cn = connected_nodes(subset(bdry_gcells,cylfacelist));
    gap_gcells= gcellset_P1 (struct('conn',cn));
    cn = connected_nodes(subset(bdry_gcells,bottomfacelist));
    hold_gcells = gcellset_P1 (struct('conn',cn));

    % Material
    prop = property_linel_iso (struct('E',E,'nu',nu));
    mater = mater_defor_ss_linel_triax (struct('property',prop));
    % Finite element block
    feb = feblock_defor_ss_nicer (struct('mater',mater,'gcells',gcells,...
        'integration_rule',simplex_nq_rule (3)));
    gapfeb = feblock_defor_gap (struct('gcells',gap_gcells,...
        'get_gap',@get_gap,'get_normal',@get_normal,'penalty',penalty));
    holdfeb = feblock_defor_ground (struct('gcells',hold_gcells,...
        'spring_constant',0.001*[1, 1, 1]*penalty));
    sfeb1 = feblock_defor_ss (struct('gcells',subset(bdry_gcells,topfacelist)));
    sfeb2 = feblock_defor_ss (struct('gcells',subset(bdry_gcells,bottomfacelist)));
    % Geometry
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    % Define the displacement field
    u   = clone(geom,'u');
    u   = u*0; % zero out
    % Apply EBC's
    %     ebc_fenids=fenode_select (fens,struct('box',[0, 0, 0, W, 0, H],'inflate',W/1000));
    %     ebc_prescribed=ebc_fenids*0+1;
    %     ebc_comp=[];% all components
    %     ebc_val=ebc_fenids*0;% zero displacement
    %     u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    %     u   = apply_ebc (u);
    % Number equations
    u   = numbereqns (u);
    get(u,'neqns')

    %     h=progressbar(mfilename);
    for step= 1:nsteps
        disp(['Step ' num2str(step)])
        travel= travel +target_travel/nsteps;
        u   = u*0; % zero out
        tic;
        K = start (sparse_sysmat, get(u, 'neqns'));
        K = assemble (K, cat(2,stiffness(feb, geom, u),stiffness(gapfeb, geom, u),stiffness(holdfeb, geom, u)));
        disp([' Stiffness matrix assembly ' num2str(toc)])
        F = start (sysvec, get(u, 'neqns'));
        lm =get(F,'vec');
         gv=reset (graphic_viewer,[]);%%% turn on for online graphics
        for augit= 1:3
            disp([' Aug Iteration ' num2str(augit)])
            F = assemble (start (sysvec, get(u, 'neqns')), gap_loads(gapfeb, geom, u));
            gl =get(F,'vec');
            tic;
            %                         us = get(K,'mat')\(-lm+gl);%bicg(get(K,'mat'),(-lm+gl), 1e-6, 140, diag(diag (get(K,'mat'))));
            %             us = bicgstab(@afun,(-lm+gl), 1e-6, 20,  []);
            %             us = pcg(@afun,(-lm+gl), 1e-6, 500,  preconditioner);
            us = gmres(@afun,(-lm+gl), 12,1e-6, 5,preconditioner);
            disp(['      Solve ' num2str(toc)])
            u = scatter_sysvec(u, us);
            lm=lm-gl;
 draw(sfeb1,gv, struct ('x', geom, 'u',(1)*u,'facecolor','red'));%%% turn on for online graphics
 draw(sfeb2,gv, struct ('x', geom, 'u',(1)*u,'facecolor','blue'));%%% turn on for online graphics
            %  draw(feb,gv, struct ('x', geom, 'u', (1)*u,'facecolor','none','edgecolor','black'));
            pause(0.5)
        end
        geom =geom+u;% update geometry
        %         if isempty(progressbar((step/nsteps),h)), return, end;
    end
    function y = afun(x)
        y = matvecprod(K, x);
    end
    function M =  preconditioner
        M=diag(K);
    end

    c =clock; disp(['Stopped ' num2str(c(4)) ':' num2str(c(5)) ':' num2str(c(6)) ' '])
    % Plot
    gv=graphic_viewer;
    gv=reset (gv,[]);
    scale=1;
    %         draw(feb,gv, struct ('x', geom, 'u', 0*u, 'facecolor','none'));
    draw(feb,gv, struct ('x', geom, 'u', (0)*u,'facecolor','red'));
    xlabel('X');
    ylabel('Y');
    zlabel('Z');
    hold on
end
