function  flat_punch
    disp('Flat punch pushed into a box');

    % Parameters:
    E=1e3;
    nu= 0.48;
    L= 300;
    W= 300;
    H= 300;
    R=400;
    nsteps = 5;
    center = [L+R, W/2, H/2];
    travel =R/4;
    dcenter = [-travel/nsteps,0, 0];
    nedges = 5;
    penalty = 100*E;

    function  gap = get_gap (surface_data,x)
            gap =  norm(center-x)-R;
            if (gap>0), gap = 0; end
        end
    function normal = get_normal(surface_data,x)
        normal=(x-center)/norm(center-x);
    end

    % Mesh
    %     [fens,gcells] = blockH20(L,W,H,nedges,nedges,nedges);
    [fens,gcells] = t4block(L,W,H,nedges,nedges,nedges);
    bdry_gcells = mesh_bdry(gcells,  []);
    cn = connected_nodes(bdry_gcells);
    gap_gcells(1:length(cn)) = deal(gcell_P1);
    for i= 1:length(cn)
        gap_gcells(i)=gcell_P1 (struct('conn',cn(i)));
    end

    % Material
    prop = property_linel_iso (struct('E',E,'nu',nu));
    mater = mater_defor_ss_linel_triax (struct('property',prop));
    % Finite element block
    feb = feblock_defor_ss_nice (struct('mater',mater,'gcells',gcells,...
        'integration_rule',simplex_nq_rule (3)));
    gapfeb = feblock_defor_gap (struct('gcells',gap_gcells,...
        'get_gap',@get_gap,'get_normal',@get_normal,'penalty',penalty));
    % Geometry
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));

%     h=progressbar(mfilename);
    for step= 1:nsteps
        disp(['Step ' num2str(step)])
        center= center +dcenter;
        % Define the displacement field
        u   = clone(geom,'u');
        u   = u*0; % zero out
        % Apply EBC's
        ebc_fenids=fenode_select (fens,struct('box',[0, 0, 0, W, 0, H],'inflate',W/1000));
        ebc_prescribed=ebc_fenids*0+1;
        ebc_comp=[];% all components
        ebc_val=ebc_fenids*0;% zero displacement
        u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
        u   = apply_ebc (u);
        % Number equations
        u   = numbereqns (u);

        K = start (sparse_sysmat, get(u, 'neqns'));
        K = assemble (K, cat(2,stiffness(feb, geom, u),stiffness(gapfeb, geom, u)));
        F = start (sysvec, get(u, 'neqns'));
        lm =get(F,'vec');
        gv=reset (graphic_viewer,[]);
        for augit= 1:3
            F = start (sysvec, get(u, 'neqns'));
            F = assemble (F, gap_loads(gapfeb, geom, u));
            gl =get(F,'vec');
%             plot(gl,'r-'); figure(gcf); pause(2); hold on
            u = scatter_sysvec(u, get(K,'mat')\(-lm+gl));
            lm=lm-gl;
%             plot(lm); figure(gcf); pause(2)
%             draw(feb,reset (graphic_viewer,[]), struct ('x', geom, 'u', (1)*u,'facecolor','red'));
 draw(feb,gv, struct ('x', geom, 'u', (1)*u,'facecolor','red'));pause(5)
        end
        % Plot
        %         gv=graphic_viewer;
        %         gv=reset (gv,[]);
        %         scale=1;
        %         %         draw(feb,gv, struct ('x', geom, 'u', 0*u, 'facecolor','none'));
        %         draw(feb,gv, struct ('x', geom, 'u', (scale)*u,'facecolor','red'));
        %         xlabel('X');
        %         ylabel('Y');
        %         zlabel('Z');
        %         hold on
        %         pause(1);
        %         close(gcf)
        geom =geom+u;% update geometry
%         if isempty(progressbar((step/nsteps),h)), return, end;
    end
    % Plot
    gv=graphic_viewer;
    gv=reset (gv,[]);
    scale=1;
    %         draw(feb,gv, struct ('x', geom, 'u', 0*u, 'facecolor','none'));
    draw(feb,gv, struct ('x', geom, 'u', (scale)*u,'facecolor','red'));
    xlabel('X');
    ylabel('Y');
    zlabel('Z');
    hold on
end
