%%  lzzuddin, Elnashai Dome frame

%% 
% 
% Reference: EULERIAN FORMULATION FOR LARGE-DISPLACEMENT ANALYSIS OF SPACE
% FRAMES, by B.  A.  lzzuddin I and A.  S.  Elnashai,  
% Journal of Engineering Mechanics, Vol.  119, No.  3,  March, 1993. 

%% 
% Parameters:
E=20650;%MPa
nu=0.3;
b=0.76;%m
h=1.22;%m
P=123.8;

%% 
% Cross-sectional properties
A=h*b;%in^2
I2=b^3*h/12;%m^4 
I3=b*h^3/12;%in^4 
IT=I2+I3;
tolerance=b/1000;

%% 
% 
X=[0,0,6.1;
    -24.38,0,0;
    -24.38*cos(60/180*pi),-24.38*sin(60/180*pi),0;
    24.38*cos(60/180*pi),-24.38*sin(60/180*pi),0;
    24.38,0,0;
    24.38*cos(60/180*pi),24.38*sin(60/180*pi),0;
    -24.38*cos(60/180*pi),24.38*sin(60/180*pi),0;
    -12.57,0,4.55;
    -12.57*cos(60/180*pi),-12.57*sin(60/180*pi),4.55;
    12.57*cos(60/180*pi),-12.57*sin(60/180*pi),4.55;
    12.57,0,4.55;
    12.57*cos(60/180*pi),12.57*sin(60/180*pi),4.55;
    -12.57*cos(60/180*pi),12.57*sin(60/180*pi),4.55]; 
members=[2,8;3,9;4,10;5,11;6,12;7,13;
    8,9;9,10;10,11;11,12;12,13;13,8;
    8,1;9,1;10,1;11,1;12,1;13,1
    ];
% Generate the mesh member by member and merge together
n=5;
Parameters=struct ('A',A,'I2',I2,'I3',I3,'IT',IT,...
    'x1x2_vector',[0 0 1], 'label',1);
[fens,gcells] = Beam_member(X(members(1,:),:),n,@gcellset_beam3,Parameters);
for i=2:size(members,1)
    [fens1,gcells1] = Beam_member(X(members(i,:),:),n,@gcellset_beam3,Parameters);
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tolerance);
    gcells= cat(gcells1,gcells2);
end
%%
% Material properties
prop = property_linel_iso (struct('E',E,'nu',nu));
mater = mater_defor_ss_linel_triax (struct('property',prop));
%% 
% Finite element block
feb = feblock_defor_ss_beam3(struct ('mater',mater, 'gcells',gcells));


%% 
% Construct the requisite fields, geometry and displacement

geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
ur  = field(struct ('name',['ur'], 'dim', 6, 'data', zeros(get(geom,'nfens'),6)));

% Apply EBC's
ebc_fenids=fenode_select(fens, struct('box', [-inf inf -inf inf 0 0],'inflate', tolerance));
ebc_prescribed=[1];
ebc_comp=[];% clamped
ebc_val=ebc_fenids*0;
ur  = set_ebc(ur, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ur  = apply_ebc (ur);

% Number equations
ur  = numbereqns (ur);
neqns=get(ur, 'neqns');

%% 
% Assemble the global discrete system

% Assemble the system matrix
K = start (sparse_sysmat, neqns);
K = assemble (K, stiffness(feb, geom, ur));
% Load
F = sysvec;
F = start (F, neqns);
evs = loads(nodal_load(struct ('id',fenode_select(fens, struct('box', update_box([],[0 0 6.1]), 'inflate', tolerance)),...
    'dir',[3],'magn',[-P])), ur);
F = assemble (F, evs);

%% 
% Solve the system and report the results
ur = scatter_sysvec(ur, K\F);

%% 
% Graphic display of the mesh and the deformed frame
gv=graphic_viewer;
gv=reset (gv,[]);
scale=1;
u=slice(ur,(1:3),'u');
rot=slice(ur,(4:6),'rot');
draw(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'facecolor','none'));
draw(feb, gv, struct ('x', geom, 'u', scale*u, 'rot', scale*rot, 'facecolor','m'));
draw_local_coordinates(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'length',0.2));

xlabel('X');
ylabel('Y');
zlabel('Z');
hold on

% draw(fens,gv, struct ('x', geom, 'u', 0*u, 'color','blue','offset',0.35));
draw_axes(gv, struct([]));
camset (gv, [-224.6266 -292.7391  216.4415         0         0    3.4053         0         0    1.0000    4.3101]);