%%  Straight cantilever, curl up with a moment at the tip


%% 
%
% Parameters:
E=1e7;% lb.in^-2
nu=0.3;
h= 3; b =1;% in
A=b*h; I2=b*h^3/12; I3=b^3*h/12; IT=0.281*h^3*b^3/(h^2+b^2);
Length=10;% in
mag=E*A/Length/2;%  lb
nel=18;% number of elements
utol=1e-6;

% Mesh
X= [-Length/2,0,0;Length/2,0,0];
Parameters=struct ('A',A,'I2',I2,'I3',I3,'IT',IT,...
    'x1x2_vector',[0 1 0], 'label',1);
[fens,gcells] = Beam_member(X,nel,@gcellset_beam3,Parameters);
end1n=fenode_select(fens, struct('box', update_box([],X(1,:))));
end2n=fenode_select(fens, struct('box', update_box([],X(2,:))));
midn=fenode_select(fens, struct('box', update_box([],mean(X))));
    
    

% Material
prop = property_linel_iso (struct('E',E,'nu',nu));
mater = mater_defor_ss_linel_triax (struct('property',prop));
% Finite element block
feb = feblock_defor_ss_beam3_corot(struct ('mater',mater, 'gcells',gcells));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
ur  = field(struct ('name',['ur'], 'dim', 6, 'data', zeros(get(geom,'nfens'),6)));
Rfield = field(struct ('name',['Rfield'], 'dim', 9, 'data', ones(get(geom,'nfens'),1)*reshape(eye(3),1,9)));

% Apply EBC's
ebc_fenids=[midn];
ebc_prescribed=[1];
ebc_comp=[];
ebc_val=0;
ur  = set_ebc(ur, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ur  = apply_ebc (ur);
% Number equations
ur  = numbereqns (ur);
neqns=get(ur, 'neqns');

gv=graphic_viewer;
    

load_parameters=1;
for load_parameter=load_parameters
    
    % Initialization
    ur1 = ur; % guess
    ur1 = apply_ebc(ur1);
    Rfield1=Rfield;
    dur = 0*ur; % this will hold displacement increment
    dur = apply_ebc(dur);
    nl1 = nodal_load(struct ('id',end1n,'dir',[1],'magn',[-load_parameter*mag]));
    nl2 = nodal_load(struct ('id',end2n,'dir',[1],'magn',[+load_parameter*mag]));
    
    iter=1;
    while 1
        feb1=feb;  % Make a copy of the state
        F = start (sysvec, neqns);
        F = assemble (F, loads(nl1, ur1));
        F = assemble (F, loads(nl2, ur1));
        [feb1,evs] = restoring_force(feb1,geom,ur1,Rfield1);       % Internal forces
        F = assemble (F, evs);
        K = start (sparse_sysmat, neqns);
        K = assemble (K, cat(2,stiffness(feb1, geom,ur1,Rfield1),stiffness_geo(feb1, geom,ur1,Rfield1)));
        dur = scatter_sysvec(dur, K\F); % Displacement increment
        ur1 = ur1 + dur;   % increment displacement
        Rfield1=update_rotation_field(Rfield1,slice(dur,(4:6),'rot'));
        disp(['   It. ' num2str(iter) ': ||du||=' num2str(norm(dur))]);
        if (max(abs(gather(dur,[],'values'))) < utol) break; end;                    % convergence check
        iter=iter+1;
    end
    [feb,ignore] = restoring_force(feb,geom,ur1,Rfield1);        % final update
    disp(['    Converged for load_parameter=' num2str(load_parameter)]); % pause
    ur = ur1;                                               % update the displacement
    Rfield=Rfield1; % update the rotations
    
    %%
    % Graphic display of the mesh and the deformed beam
    gv=reset (gv,[]);
    scale=1;
    u=slice(ur1,(1:3),'u');
    rot=slice(ur,(4:6),'rot');
    draw(feb, gv, struct ('x', geom, 'u', 0*u, 'rot', 0*rot, 'facecolor','none'));
    draw(feb, gv, struct ('x', geom, 'u', u, 'R', Rfield1, 'facecolor','g','facealpha',0.5));
%         draw_local_coordinates(feb, gv, struct ('x', geom, 'u', scale*u, 'rot', 0*rot, 'length',25));
    
%     xlabel('X');
%     ylabel('Y');
%     zlabel('Z');
%     hold on 
    
    %     draw(fens,gv, struct ('x', geom, 'u', 0*u, 'color','blue','offset',0.35));
        draw_axes(gv, struct ( 'length',2.5)); 
    %        camset (gv, [853.6214  -90.7134  185.3798   15.4140   49.5544  -26.5148         0         0    1.0000 5.0831]);
    pause(1)
end

