%%  Argyris L-frame, out-of-plane load, nonlinear.

function CBArgyrLFrameVibrationSmAmp
    %%
    % Parameters:
    E=71240.0;%MPa
    nu=0.31;% Poisson ratio
    rho=5e-9;
    b=3; h=30; L=240;% cross-sectional dimensions and length of each leg in millimeters
    Fmag= 250;
    utol=1e-3;
    dt=0.001;
    tend=0.3;
    Newmarkg = 1/2; Newmarkb = 1/4*(1/2+Newmarkg)^2;
    % Newmarkg = 0.6; Newmarkb = 1/4*(1/2+Newmarkg)^2;
    maxit=24;
    graphics=0;
    Report =@(x) (disp(x) );
    %%
    % Choose the mass formulation:
    consistent_no_rotation_inertia=0;
    consistent_with_rotation_inertia=1;
    lumped_diagonal_no_rotation_inertia=2;
    lumped_diagonal_with_rotation_inertia=3;
    mass_type=1;

    %%
    % Mesh
    n=8;
    tolerance=L/n/100;
    Parameters=struct ('A',b*h,'I2',b*h^3/12,'I3',b^3*h/12,'IT',b^3*h/3,...
        'x1x2_vector',[0 0 1], 'label',1);
    [fens1,gcells1] = Beam_member([0,L,0;L,L,0],n,@gcellset_beam3,Parameters);
    [fens2,gcells2] = Beam_member([L,L,0;L,0,0],n,@gcellset_beam3,Parameters);
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens2, gcells2, tolerance);
    gcells= cat(gcells1,gcells2);
    
    % The clamped end is
    clampedn=fenode_select(fens, struct('box', update_box([],[0,L,0]), 'inflate', tolerance));
    % The force is applied at the elbow
    elbown=fenode_select(fens, struct('box', update_box([],[L,L,0]), 'inflate', tolerance));
    % The force is applied at the elbow
    tipn=fenode_select(fens, struct('box', update_box([],[L,0,0]), 'inflate', tolerance));
    
    %%
    % Properties
    prop = property_linel_iso (struct('E',E,'nu',nu,'rho',rho));
    mater = mater_defor_ss_linel_triax (struct('property',prop));
    
    %%
    % Finite element block
    feb = feblock_defor_ss_corot_beam(struct ('mater',mater, 'gcells',gcells,'mass_type',mass_type));
    
    %%
    % Initialize configuration variables
    geom0 = field(struct ('name',['geom0'], 'dim', 3, 'fens',fens));
    u=0*geom0;
    Rfield = field(struct ('name',['Rfield'], 'dim', 9, 'data', ones(get(geom0,'nfens'),1)*reshape(eye(3),1,9)));
    Rfield0=Rfield;
    % Define the displacement increment field
    dchi  = field(struct ('name',['dchi'], 'dim', 6, 'data', zeros(get(geom0,'nfens'),6)));
    
    % Apply EBC's
    ebc_fenids=[clampedn];
    ebc_prescribed=[1];
    ebc_comp=[];
    ebc_val=0;
    dchi = set_ebc(dchi, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    dchi = apply_ebc (dchi);
    % Number equations
    dchi = numbereqns (dchi);
    neqns=get(dchi, 'neqns');
    
    
    if (graphics)
        gv=graphic_viewer;
    else
        plot_reference;
    end
    
    % Now comes the nonlinear solution
    tup = 1;
    dchi = dchi*0; % zero out the displacement
    v = dchi*0; % zero out the Velocity
    a = dchi*0; % zero out the Acceleration
    utol = 1e-15*get(dchi, 'neqns');
    
    K = start (sparse_sysmat, get(dchi, 'neqns'));
    M = start (sparse_sysmat, get(dchi, 'neqns'));
    
    
    t=0; %
    while (t <= tend)
        t = t + dt;
        Report(['Time ' num2str(t) ]); % pause
        % Initialization
        dchi = apply_ebc(dchi);% Apply boundary conditions
        u1 = u; % guess
        Rfield1=Rfield; % guess
        stepdchi = 0*apply_ebc(dchi);% Total increment in current step
        a1 = -(1/Newmarkb/dt)*v -(1/2-Newmarkb)/Newmarkb*a;
        v1 = v + dt*((1-Newmarkg)*a + Newmarkg*a1);
        dchipv =gather_sysvec(dt*v +(dt^2/2*(1-2*Newmarkb))*a);
        vpv =gather_sysvec(v +(dt*(1-Newmarkg))*a);
        nl = nodal_load(struct ('id',elbown,'dir',[3],'magn',[(t<0.2)*((t<0.1)*t+(t>0.1)*(0.2-t))*Fmag]));
        
        iter=1;
        while 1
            feb1=feb;
            F = start (sysvec, get(dchi, 'neqns'));
            F = assemble (F, loads(nl, dchi));
            [feb,evs] = restoring_force(feb,geom0,u1,Rfield1,dchi);       % Internal forces
            F = assemble (F, evs);
            K =assemble (K,cat(2,stiffness(feb,geom0,u1,Rfield1,dchi),stiffness_geo(feb,geom0,u1,Rfield1,dchi)));
            Km=get(K, 'mat');
            M =assemble (M,mass(feb,geom0,u1,Rfield1,dchi));
            Mm=get(M, 'mat');
            rhs=get(F,'vec')...
                +Mm*((-1/(Newmarkb*dt^2))*gather_sysvec(stepdchi)+(1/(Newmarkb*dt^2))*dchipv);
            dchi = scatter_sysvec(dchi, (Km+(1/(Newmarkb*dt^2))*Mm)\rhs); % Displacement increment
            %                 max(abs(get(F,'vec')))
            u1 = u1 + slice(dchi,(1:3),'transl');   % increment displacement
            stepdchi = stepdchi + dchi;
            v1 = v1 + (Newmarkg/Newmarkb/dt)*dchi;
            a1 = a1 + (1/Newmarkb/dt^2)*dchi;
            Rfield1=update_rotation_field(Rfield1,slice(dchi,(4:6),'rotat'));
            Report(['   It. ' num2str(iter) ': ||du||=' num2str(norm(dchi))]);
            if (max(abs(gather(dchi,[],'values'))) < utol) break; end;% convergence check
            if (iter >maxit)% bailout for failed convergence
                error( [' Possible failed convergence']);
            end
            K = reinitialize (K);
            M = reinitialize (M);
            iter=iter+1;
        end
        [feb,ignore] = restoring_force(feb,geom0,u1,Rfield1,dchi);        % final update
        Report(['    Converged for t=' num2str(t)]); % pause
        u = u1;       % update the displacement
        Rfield=Rfield1; % update the rotations
        v = v1;       % update the velocities
        a = a1;       % update the accelerations
        
        if graphics
            gv=reset(gv,[]);
            draw(feb, gv, struct ('x', geom0, 'u', 0*u1, 'R', Rfield0, 'facecolor','r'));
            draw(feb, gv, struct ('x', geom0, 'u', u1, 'R', Rfield1, 'facecolor','g'));
            %         draw_local_coordinates(feb, gv, struct ('x', geom0, 'u', u1, 'R', Rfield1, 'length',12.5));
            %         camset(gv, 1.0e+003 *[-1.7885   -3.9427    1.7590
            %         0.0096    0.0029    0.0071         0         0    0.0010    0.0002]);
            drawnow;
        else
            tipu=gather(u1,tipn, 'values', 'noreshape');
            elbowu=gather(u1,elbown, 'values', 'noreshape');
            plot(t,tipu(1), 'rv');
            hold on
            plot(t,tipu(2), 'gv');
            plot(t,tipu(3), 'bv');
            plot(t,elbowu(1), 'ro');
            hold on
            plot(t,elbowu(2), 'go');
            plot(t,elbowu(3), 'bo');
            figure(gcf);
        end
    end
    function plot_reference()
        tipus =[-0.0000    0.0000    0.0000
   -0.0000    0.0000   -0.0003
   -0.0000    0.0000   -0.0031
   -0.0000    0.0000   -0.0128
    0.0000    0.0000   -0.0325
    0.0000    0.0000   -0.0612
    0.0001    0.0001   -0.0966
    0.0003    0.0003   -0.1374
    0.0006    0.0005   -0.1841
    0.0012    0.0009   -0.2376
    0.0020    0.0016   -0.2956
    0.0032    0.0025   -0.3522
    0.0048    0.0036   -0.4009
    0.0069    0.0051   -0.4378
    0.0094    0.0067   -0.4612
    0.0123    0.0086   -0.4681
    0.0153    0.0106   -0.4530
    0.0185    0.0125   -0.4085
    0.0215    0.0141   -0.3290
    0.0242    0.0154   -0.2123
    0.0262    0.0163   -0.0580
    0.0272    0.0166    0.1361
    0.0272    0.0164    0.3738
    0.0259    0.0154    0.6574
    0.0232    0.0139    0.9864
    0.0189    0.0119    1.3571
    0.0129    0.0097    1.7656
    0.0053    0.0072    2.2107
   -0.0039    0.0048    2.6915
   -0.0148    0.0025    3.2042
   -0.0272    0.0005    3.7422
   -0.0411   -0.0009    4.2978
   -0.0563   -0.0019    4.8652
   -0.0728   -0.0023    5.4420
   -0.0905   -0.0021    6.0256
   -0.1095   -0.0014    6.6106
   -0.1295   -0.0004    7.1901
   -0.1505    0.0009    7.7586
   -0.1723    0.0022    8.3138
   -0.1950    0.0036    8.8564
   -0.2187    0.0050    9.3861
   -0.2430    0.0062    9.9003
   -0.2679    0.0072   10.3966
   -0.2931    0.0078   10.8756
   -0.3187    0.0083   11.3405
   -0.3449    0.0086   11.7950
   -0.3717    0.0090   12.2407
   -0.3989    0.0092   12.6771
   -0.4265    0.0093   13.1052
   -0.4547    0.0095   13.5288
   -0.4837    0.0099   13.9526
   -0.5137    0.0106   14.3788
   -0.5446    0.0116   14.8063
   -0.5763    0.0129   15.2331
   -0.6086    0.0145   15.6587
   -0.6417    0.0165   16.0850
   -0.6756    0.0192   16.5131
   -0.7100    0.0224   16.9398
   -0.7444    0.0261   17.3596
   -0.7783    0.0300   17.7674
   -0.8114    0.0342   18.1607
   -0.8436    0.0388   18.5379
   -0.8746    0.0435   18.8962
   -0.9039    0.0482   19.2293
   -0.9307    0.0523   19.5307
   -0.9548    0.0557   19.7972
   -0.9761    0.0583   20.0276
   -0.9948    0.0601   20.2212
   -1.0106    0.0608   20.3754
   -1.0229    0.0602   20.4865
   -1.0316    0.0582   20.5532
   -1.0367    0.0548   20.5784
   -1.0388    0.0505   20.5663
   -1.0378    0.0455   20.5200
   -1.0337    0.0399   20.4406
   -1.0264    0.0336   20.3297
   -1.0162    0.0270   20.1922
   -1.0038    0.0205   20.0363
   -0.9901    0.0145   19.8695
   -0.9751    0.0090   19.6964
   -0.9593    0.0040   19.5198
   -0.9430   -0.0005   19.3437
   -0.9270   -0.0044   19.1745
   -0.9120   -0.0075   19.0194
   -0.8988   -0.0099   18.8829
   -0.8872   -0.0117   18.7659
   -0.8776   -0.0133   18.6686
   -0.8702   -0.0146   18.5932
   -0.8653   -0.0155   18.5426
   -0.8632   -0.0161   18.5184
   -0.8635   -0.0164   18.5185
   -0.8659   -0.0165   18.5388
   -0.8700   -0.0167   18.5765
   -0.8758   -0.0167   18.6318
   -0.8833   -0.0166   18.7046
   -0.8922   -0.0164   18.7919
   -0.9020   -0.0162   18.8891
   -0.9122   -0.0161   18.9912
   -0.9226   -0.0163   19.0968
   -0.9335   -0.0165   19.2077
   -0.9450   -0.0169   19.3247
   -0.9566   -0.0173   19.4464
   -0.9683   -0.0176   19.5749
   -0.9810   -0.0177   19.7190
   -0.9961   -0.0171   19.8879
   -1.0145   -0.0159   20.0848
   -1.0362   -0.0145   20.3076
   -1.0614   -0.0131   20.5549
   -1.0904   -0.0116   20.8296
   -1.1240   -0.0093   21.1378
   -1.1620   -0.0059   21.4805
   -1.2027   -0.0009   21.8501
   -1.2446    0.0055   22.2356
   -1.2865    0.0137   22.6300
   -1.3279    0.0238   23.0310
   -1.3687    0.0361   23.4365
   -1.4080    0.0504   23.8375
   -1.4443    0.0658   24.2186
   -1.4760    0.0814   24.5654
   -1.5023    0.0967   24.8702
   -1.5231    0.1118   25.1295
   -1.5383    0.1265   25.3375
   -1.5466    0.1397   25.4836
   -1.5466    0.1501   25.5567
   -1.5382    0.1571   25.5508
   -1.5225    0.1606   25.4675
   -1.5009    0.1611   25.3096
   -1.4736    0.1581   25.0757
   -1.4399    0.1512   24.7623
   -1.3998    0.1406   24.3700
   -1.3539    0.1273   23.9065
   -1.3033    0.1129   23.3845
   -1.2484    0.0983   22.8135
   -1.1892    0.0840   22.1964
   -1.1258    0.0701   21.5355
   -1.0595    0.0570   20.8397
   -0.9922    0.0453   20.1229
   -0.9256    0.0354   19.3988
   -0.8609    0.0272   18.6746
   -0.7980    0.0202   17.9505
   -0.7369    0.0141   17.2280
   -0.6786    0.0093   16.5142
   -0.6235    0.0060   15.8173
   -0.5717    0.0042   15.1409
   -0.5227    0.0032   14.4821
   -0.4762    0.0028   13.8346
   -0.4325    0.0026   13.1962
   -0.3920    0.0025   12.5691
   -0.3545    0.0024   11.9533
   -0.3196    0.0022   11.3424
   -0.2867    0.0019   10.7263
   -0.2550    0.0012   10.0983
   -0.2242    0.0005    9.4583
   -0.1945   -0.0000    8.8094
   -0.1662   -0.0003    8.1508
   -0.1392   -0.0005    7.4757
   -0.1135   -0.0009    6.7785
   -0.0895   -0.0015    6.0607
   -0.0679   -0.0018    5.3308
   -0.0486   -0.0015    4.5980
   -0.0309   -0.0004    3.8666
   -0.0143    0.0018    3.1370
    0.0014    0.0056    2.4127
    0.0163    0.0111    1.7052
    0.0302    0.0180    1.0284
    0.0431    0.0258    0.3928
    0.0544    0.0339   -0.1964
    0.0634    0.0419   -0.7361
    0.0697    0.0494   -1.2185
    0.0735    0.0555   -1.6318
    0.0752    0.0598   -1.9673
    0.0749    0.0622   -2.2238
    0.0730    0.0629   -2.4046
    0.0694    0.0618   -2.5116
    0.0644    0.0589   -2.5422
    0.0580    0.0540   -2.4929
    0.0505    0.0473   -2.3672
    0.0423    0.0395   -2.1768
    0.0334    0.0313   -1.9345
    0.0245    0.0232   -1.6483
    0.0165    0.0158   -1.3215
    0.0102    0.0094   -0.9584
    0.0054    0.0046   -0.5702
    0.0022    0.0016   -0.1725
    0.0001    0.0002    0.2220
   -0.0010   -0.0001    0.6081
   -0.0018    0.0003    0.9839
   -0.0032    0.0011    1.3447
   -0.0052    0.0021    1.6819
   -0.0074    0.0030    1.9874
   -0.0097    0.0037    2.2595
   -0.0119    0.0044    2.5030
   -0.0141    0.0052    2.7222
   -0.0159    0.0060    2.9161
   -0.0175    0.0066    3.0822
   -0.0192    0.0068    3.2222
   -0.0212    0.0067    3.3442
   -0.0237    0.0064    3.4591
   -0.0265    0.0059    3.5723
   -0.0293    0.0055    3.6824
   -0.0318    0.0054    3.7871
   -0.0337    0.0056    3.8896
   -0.0348    0.0064    3.9951
   -0.0354    0.0077    4.1049
   -0.0359    0.0094    4.2136
   -0.0361    0.0111    4.3139
   -0.0360    0.0127    4.4017
   -0.0360    0.0143    4.4768
   -0.0360    0.0160    4.5382
   -0.0355    0.0177    4.5801
   -0.0340    0.0194    4.5936
   -0.0314    0.0210    4.5722
   -0.0279    0.0225    4.5151
   -0.0239    0.0236    4.4237
   -0.0199    0.0241    4.2961
   -0.0164    0.0237    4.1257
   -0.0136    0.0222    3.9071
   -0.0114    0.0197    3.6411
   -0.0098    0.0164    3.3347
   -0.0086    0.0128    2.9949
   -0.0074    0.0095    2.6237
   -0.0060    0.0064    2.2195
   -0.0041    0.0039    1.7840
   -0.0021    0.0020    1.3260
   -0.0006    0.0009    0.8573
    0.0003    0.0004    0.3872
    0.0008    0.0004   -0.0807
    0.0007    0.0009   -0.5442
    0.0001    0.0021   -0.9974
   -0.0009    0.0040   -1.4303
   -0.0018    0.0063   -1.8343
   -0.0024    0.0087   -2.2064
   -0.0032    0.0113   -2.5475
   -0.0046    0.0138   -2.8571
   -0.0067    0.0157   -3.1304
   -0.0096    0.0167   -3.3624
   -0.0132    0.0168   -3.5532
   -0.0173    0.0161   -3.7092
   -0.0215    0.0152   -3.8376
   -0.0252    0.0140   -3.9408
   -0.0282    0.0129   -4.0167
   -0.0303    0.0120   -4.0648
   -0.0315    0.0111   -4.0910
   -0.0322    0.0103   -4.1052
   -0.0329    0.0097   -4.1147
   -0.0339    0.0091   -4.1201
   -0.0349    0.0083   -4.1188
   -0.0358    0.0074   -4.1105
   -0.0364    0.0068   -4.0998
   -0.0366    0.0067   -4.0918
   -0.0362    0.0071   -4.0862
   -0.0349    0.0080   -4.0777
   -0.0329    0.0091   -4.0610
   -0.0307    0.0103   -4.0350
   -0.0284    0.0115   -4.0005
   -0.0263    0.0126   -3.9558
   -0.0243    0.0134   -3.8935
   -0.0222    0.0140   -3.8048
   -0.0197    0.0143   -3.6855
   -0.0165    0.0144   -3.5370
   -0.0128    0.0145   -3.3611
   -0.0091    0.0144   -3.1548
   -0.0056    0.0139   -2.9109
   -0.0024    0.0127   -2.6248
   -0.0002    0.0107   -2.2989
    0.0008    0.0083   -1.9410
    0.0007    0.0057   -1.5570
    0.0001    0.0031   -1.1480
   -0.0005    0.0009   -0.7132
   -0.0011   -0.0005   -0.2561
   -0.0015   -0.0008    0.2139
   -0.0017   -0.0002    0.6856
   -0.0018    0.0013    1.1519
   -0.0022    0.0035    1.6100
   -0.0034    0.0061    2.0562
   -0.0054    0.0091    2.4825
   -0.0077    0.0120    2.8784
   -0.0103    0.0149    3.2372
   -0.0129    0.0176    3.5582
   -0.0153    0.0203    3.8428
   -0.0175    0.0226    4.0890
   -0.0198    0.0244    4.2907
   -0.0222    0.0253    4.4434
   -0.0249    0.0251    4.5491
   -0.0278    0.0240    4.6154
   -0.0311    0.0222    4.6497
   -0.0343    0.0200    4.6534
   -0.0369    0.0176    4.6248
   -0.0383    0.0151    4.5651
   -0.0385    0.0129    4.4817
   -0.0379    0.0113    4.3846
   -0.0366    0.0102    4.2802
   -0.0350    0.0092    4.1689
   -0.0332    0.0082    4.0498
   -0.0317    0.0071    3.9253
   -0.0306    0.0061    3.8016
   -0.0295    0.0053    3.6827
   -0.0281    0.0048    3.5669
   -0.0263    0.0047    3.4491
   -0.0238    0.0050    3.3262];

elbowus=[0.0000   -0.0000    0.0019
   -0.0000   -0.0000    0.0098
   -0.0000   -0.0000    0.0273
   -0.0000   -0.0000    0.0560
   -0.0000   -0.0000    0.0979
   -0.0001   -0.0001    0.1566
   -0.0002   -0.0001    0.2364
   -0.0003   -0.0002    0.3401
   -0.0006   -0.0004    0.4668
   -0.0010   -0.0006    0.6150
   -0.0016   -0.0009    0.7837
   -0.0024   -0.0012    0.9736
   -0.0036   -0.0017    1.1849
   -0.0051   -0.0022    1.4149
   -0.0070   -0.0028    1.6588
   -0.0093   -0.0034    1.9127
   -0.0119   -0.0040    2.1743
   -0.0151   -0.0048    2.4428
   -0.0186   -0.0055    2.7161
   -0.0226   -0.0063    2.9901
   -0.0268   -0.0070    3.2604
   -0.0313   -0.0077    3.5249
   -0.0361   -0.0083    3.7840
   -0.0411   -0.0088    4.0390
   -0.0464   -0.0092    4.2892
   -0.0518   -0.0094    4.5330
   -0.0574   -0.0095    4.7701
   -0.0631   -0.0093    5.0030
   -0.0691   -0.0090    5.2358
   -0.0755   -0.0084    5.4720
   -0.0824   -0.0077    5.7125
   -0.0896   -0.0068    5.9582
   -0.0974   -0.0057    6.2118
   -0.1059   -0.0045    6.4776
   -0.1154   -0.0032    6.7598
   -0.1259   -0.0018    7.0602
   -0.1375   -0.0004    7.3781
   -0.1503    0.0009    7.7132
   -0.1643    0.0021    8.0671
   -0.1799    0.0032    8.4415
   -0.1971    0.0043    8.8362
   -0.2160    0.0053    9.2482
   -0.2362    0.0060    9.6729
   -0.2578    0.0066   10.1074
   -0.2807    0.0069   10.5504
   -0.3051    0.0073   10.9998
   -0.3307    0.0076   11.4512
   -0.3570    0.0079   11.8985
   -0.3837    0.0081   12.3362
   -0.4105    0.0083   12.7616
   -0.4373    0.0086   13.1730
   -0.4639    0.0092   13.5680
   -0.4899    0.0101   13.9424
   -0.5148    0.0110   14.2920
   -0.5383    0.0122   14.6154
   -0.5605    0.0136   14.9137
   -0.5815    0.0155   15.1885
   -0.6010    0.0177   15.4398
   -0.6190    0.0200   15.6672
   -0.6352    0.0224   15.8709
   -0.6501    0.0248   16.0550
   -0.6640    0.0274   16.2244
   -0.6772    0.0301   16.3825
   -0.6898    0.0327   16.5312
   -0.7017    0.0349   16.6718
   -0.7131    0.0367   16.8074
   -0.7247    0.0380   16.9430
   -0.7368    0.0391   17.0830
   -0.7496    0.0397   17.2284
   -0.7629    0.0396   17.3791
   -0.7767    0.0387   17.5348
   -0.7910    0.0371   17.6971
   -0.8064    0.0350   17.8681
   -0.8227    0.0325   18.0473
   -0.8396    0.0295   18.2317
   -0.8568    0.0258   18.4177
   -0.8740    0.0216   18.6031
   -0.8913    0.0172   18.7875
   -0.9087    0.0128   18.9698
   -0.9258    0.0084   19.1464
   -0.9419    0.0039   19.3127
   -0.9568   -0.0005   19.4655
   -0.9703   -0.0048   19.6041
   -0.9828   -0.0086   19.7293
   -0.9940   -0.0118   19.8403
   -1.0037   -0.0147   19.9349
   -1.0115   -0.0172   20.0118
   -1.0175   -0.0193   20.0723
   -1.0224   -0.0208   20.1199
   -1.0265   -0.0218   20.1586
   -1.0299   -0.0223   20.1901
   -1.0327   -0.0226   20.2154
   -1.0351   -0.0226   20.2376
   -1.0376   -0.0224   20.2618
   -1.0411   -0.0220   20.2942
   -1.0459   -0.0215   20.3388
   -1.0522   -0.0210   20.3975
   -1.0600   -0.0208   20.4720
   -1.0698   -0.0209   20.5661
   -1.0822   -0.0212   20.6841
   -1.0971   -0.0217   20.8256
   -1.1135   -0.0223   20.9823
   -1.1304   -0.0229   21.1457
   -1.1476   -0.0231   21.3116
   -1.1652   -0.0225   21.4766
   -1.1824   -0.0211   21.6341
   -1.1977   -0.0191   21.7730
   -1.2097   -0.0169   21.8839
   -1.2182   -0.0144   21.9634
   -1.2234   -0.0110   22.0123
   -1.2254   -0.0066   22.0304
   -1.2238   -0.0010   22.0141
   -1.2177    0.0054   21.9588
   -1.2072    0.0125   21.8646
   -1.1931    0.0203   21.7379
   -1.1767    0.0289   21.5857
   -1.1581    0.0378   21.4121
   -1.1374    0.0465   21.2174
   -1.1146    0.0543   21.0037
   -1.0906    0.0610   20.7783
   -1.0669    0.0671   20.5509
   -1.0443    0.0729   20.3283
   -1.0225    0.0780   20.1117
   -1.0012    0.0817   19.9001
   -0.9804    0.0838   19.6954
   -0.9611    0.0847   19.5032
   -0.9438    0.0847   19.3276
   -0.9283    0.0835   19.1673
   -0.9138    0.0806   19.0161
   -0.8994    0.0759   18.8679
   -0.8851    0.0700   18.7208
   -0.8710    0.0636   18.5750
   -0.8570    0.0574   18.4268
   -0.8422    0.0511   18.2675
   -0.8254    0.0448   18.0873
   -0.8062    0.0384   17.8798
   -0.7848    0.0323   17.6443
   -0.7614    0.0268   17.3795
   -0.7354    0.0219   17.0804
   -0.7063    0.0171   16.7398
   -0.6738    0.0125   16.3533
   -0.6385    0.0086   15.9226
   -0.6014    0.0058   15.4535
   -0.5630    0.0041   14.9495
   -0.5233    0.0032   14.4102
   -0.4825    0.0028   13.8361
   -0.4413    0.0026   13.2326
   -0.4007    0.0025   12.6104
   -0.3618    0.0024   11.9803
   -0.3249    0.0022   11.3485
   -0.2900    0.0019   10.7179
   -0.2573    0.0012   10.0936
   -0.2273    0.0005    9.4851
   -0.2003   -0.0000    8.9036
   -0.1766   -0.0004    8.3561
   -0.1557   -0.0008    7.8438
   -0.1374   -0.0017    7.3662
   -0.1215   -0.0030    6.9258
   -0.1079   -0.0048    6.5278
   -0.0966   -0.0067    6.1754
   -0.0872   -0.0088    5.8654
   -0.0792   -0.0108    5.5906
   -0.0724   -0.0125    5.3451
   -0.0665   -0.0136    5.1269
   -0.0616   -0.0143    4.9356
   -0.0575   -0.0147    4.7668
   -0.0538   -0.0150    4.6111
   -0.0503   -0.0152    4.4585
   -0.0468   -0.0152    4.3042
   -0.0433   -0.0153    4.1476
   -0.0401   -0.0154    3.9884
   -0.0368   -0.0152    3.8221
   -0.0335   -0.0146    3.6419
   -0.0299   -0.0134    3.4446
   -0.0263   -0.0119    3.2332
   -0.0229   -0.0103    3.0134
   -0.0196   -0.0090    2.7889
   -0.0166   -0.0079    2.5596
   -0.0137   -0.0071    2.3254
   -0.0111   -0.0064    2.0914
   -0.0088   -0.0057    1.8672
   -0.0070   -0.0051    1.6611
   -0.0056   -0.0042    1.4769
   -0.0045   -0.0030    1.3149
   -0.0036   -0.0017    1.1770
   -0.0029   -0.0006    1.0698
   -0.0026    0.0003    1.0003
   -0.0024    0.0008    0.9711
   -0.0025    0.0010    0.9787
   -0.0027    0.0009    1.0178
   -0.0030    0.0007    1.0865
   -0.0036    0.0007    1.1858
   -0.0044    0.0010    1.3142
   -0.0054    0.0015    1.4649
   -0.0067    0.0021    1.6266
   -0.0081    0.0025    1.7899
   -0.0095    0.0026    1.9502
   -0.0111    0.0025    2.1045
   -0.0126    0.0022    2.2462
   -0.0140    0.0019    2.3650
   -0.0150    0.0016    2.4521
   -0.0157    0.0016    2.5065
   -0.0160    0.0019    2.5316
   -0.0160    0.0025    2.5289
   -0.0156    0.0032    2.4964
   -0.0148    0.0037    2.4324
   -0.0137    0.0038    2.3397
   -0.0124    0.0036    2.2256
   -0.0110    0.0034    2.0972
   -0.0096    0.0032    1.9575
   -0.0082    0.0030    1.8067
   -0.0069    0.0029    1.6470
   -0.0056    0.0030    1.4847
   -0.0045    0.0033    1.3280
   -0.0035    0.0036    1.1815
   -0.0028    0.0036    1.0451
   -0.0022    0.0033    0.9172
   -0.0016    0.0025    0.7992
   -0.0012    0.0016    0.6954
   -0.0010    0.0008    0.6086
   -0.0007    0.0002    0.5369
   -0.0006   -0.0000    0.4745
   -0.0004   -0.0001    0.4171
   -0.0003    0.0000    0.3643
   -0.0003    0.0002    0.3170
   -0.0002    0.0004    0.2729
   -0.0001    0.0002    0.2253
   -0.0001   -0.0001    0.1674
   -0.0000   -0.0004    0.0961
   -0.0000   -0.0004    0.0130
   -0.0000   -0.0003   -0.0810
   -0.0001    0.0001   -0.1885
   -0.0003    0.0008   -0.3141
   -0.0005    0.0016   -0.4601
   -0.0010    0.0023   -0.6230
   -0.0016    0.0027   -0.7971
   -0.0024    0.0027   -0.9785
   -0.0034    0.0025   -1.1672
   -0.0047    0.0022   -1.3631
   -0.0061    0.0021   -1.5618
   -0.0077    0.0021   -1.7552
   -0.0094    0.0024   -1.9356
   -0.0110    0.0027   -2.0998
   -0.0126    0.0031   -2.2473
   -0.0141    0.0034   -2.3761
   -0.0154    0.0034   -2.4804
   -0.0163    0.0031   -2.5534
   -0.0168    0.0026   -2.5920
   -0.0168    0.0021   -2.5983
   -0.0165    0.0019   -2.5758
   -0.0159    0.0020   -2.5246
   -0.0149    0.0024   -2.4424
   -0.0136    0.0028   -2.3284
   -0.0120    0.0031   -2.1869
   -0.0102    0.0033   -2.0258
   -0.0086    0.0032   -1.8513
   -0.0070    0.0029   -1.6656
   -0.0054    0.0024   -1.4692
   -0.0041    0.0019   -1.2658
   -0.0029    0.0015   -1.0630
   -0.0019    0.0013   -0.8686
   -0.0012    0.0015   -0.6862
   -0.0007    0.0017   -0.5151
   -0.0003    0.0017   -0.3549
   -0.0001    0.0014   -0.2086
   -0.0000    0.0009   -0.0809
   -0.0000    0.0004    0.0260
   -0.0000   -0.0003    0.1156
   -0.0001   -0.0009    0.1932
   -0.0002   -0.0011    0.2618
   -0.0003   -0.0009    0.3208
   -0.0003   -0.0004    0.3694
   -0.0004    0.0002    0.4115
   -0.0005    0.0006    0.4542
   -0.0006    0.0010    0.5040
   -0.0008    0.0012    0.5623
   -0.0010    0.0013    0.6277
   -0.0013    0.0012    0.7003
   -0.0016    0.0013    0.7839
   -0.0020    0.0017    0.8833
   -0.0025    0.0024    0.9997
   -0.0032    0.0032    1.1289
   -0.0041    0.0039    1.2657
   -0.0050    0.0042    1.4082
   -0.0061    0.0042    1.5570
   -0.0074    0.0039    1.7115
   -0.0088    0.0036    1.8662
   -0.0102    0.0032    2.0129
   -0.0115    0.0027    2.1453
   -0.0128    0.0026    2.2616
   -0.0139    0.0027    2.3617
   -0.0149    0.0031    2.4424
   -0.0156    0.0033    2.4972
   -0.0159    0.0033    2.5199
   -0.0157    0.0029    2.5090
   -0.0152    0.0024    2.4675
   -0.0143    0.0019    2.3983
   -0.0132    0.0014    2.3007
   -0.0118    0.0013    2.1719
   -0.0101    0.0014    2.0126];
        
        t=linspace(0, 0.3, size(tipus,1))
        plot(t,tipus(:,1), 'r-');
        hold on
        plot(t,tipus(:,2), 'g-');
        plot(t,tipus(:,3), 'b-');
        plot(t,elbowus(:,1), 'r-');
        hold on
        plot(t,elbowus(:,2), 'g-');
        plot(t,elbowus(:,3), 'b-');
        figure(gcf);
        set_graphics_defaults
        labels(' Time [s]',' Deflection [mm]');
        grid on

    end
end
