%% Spinning "top" made up of four bars
% 
% Parameters:
E=30002*1000;%30002ksi
nu=0.3;
radius_internal=2.5/2;%in
radius_external=6.25/2;%in
L=10*12;% in
g=32.17*12; % in/second^2
rho=490/12^3/g; %lb/ft^3
Omegaini=13;
q=[0;0;-32];% 1200 lbf/ft
graphics= false;
dt=1/Omegaini/10;
tend=400*dt;
Newmarkg = 1/2; Newmarkb = 1/4*(1/2+Newmarkg)^2;
% Newmarkg = 0.6; Newmarkb = 1/4*(1/2+Newmarkg)^2;
maxit=12;
Report =@(x) (disp(x) );
%%
% Cross-sectional properties
A=pi*(radius_external^2-radius_internal^2);%in^2
I2=pi/4*(radius_external^4-radius_internal^4);;%cm^4 
I3=pi/4*(radius_external^4-radius_internal^4);;%cm^4 
IT=pi/2*(radius_external^4-radius_internal^4);




%% 
% 
n=2;
Parameters=struct ('A',A,'I2',I2,'I3',I3,'IT',IT,...
    'x1x2_vector',[1 0 0], 'label',1);
tolerance=L/n/100;
a= [1,0.2,0]';
[fens,gcells]  = Beam_member([[0 0 0];L*a'],n,@gcellset_beam3,Parameters);
[fens1,gcells1]  = Beam_member([[0 0 0];(L*rotmat(120/180*pi*[1;0;0])*a)'],n,@gcellset_beam3,Parameters);
[fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tolerance);
gcells= cat(gcells1,gcells2);
[fens1,gcells1]  = Beam_member([[0 0 0];(L*rotmat(240/180*pi*[1;0;0])*a)'],n,@gcellset_beam3,Parameters);
[fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tolerance);
gcells= cat(gcells1,gcells2);
basen=fenode_select(fens, struct('box', update_box([],[0 0 0])));
tipn=fenode_select(fens, struct('box', update_box([],L*a')));

%% 
% Material properties
prop = property_linel_iso (struct('E',E,'nu',nu,'rho',rho));
mater = mater_defor_ss_linel_triax (struct('property',prop));
%% 
% Finite element block
feb = feblock_defor_ss_corot_beam(struct ('mater',mater, 'gcells',gcells));


%% 
% Initialize configuration variables
geom0 = field(struct ('name',['geom0'], 'dim', 3, 'fens',fens));
u=0*geom0;
Rfield = field(struct ('name',['Rfield'], 'dim', 9, 'data', ones(get(geom0,'nfens'),1)*reshape(eye(3),1,9)));
Rfield0=Rfield;
% Define the displacement increment field
chiincr  = field(struct ('name',['chiincr'], 'dim', 6, 'data', zeros(get(geom0,'nfens'),6)));

% Apply EBC's
chiincr  = set_ebc(chiincr, basen, 1, [1,2,3], 0);
chiincr  = apply_ebc (chiincr);

% Number equations
chiincr  = numbereqns (chiincr);
neqns=get(chiincr, 'neqns');


if graphics, gv=graphic_viewer; end


% Now comes the nonlinear solution
tup = 1;
chiincr = chiincr*0; % zero out the displacement
v = chiincr*0; % zero out the Velocity
xyz = gather(geom0,(1:count(fens)),'values','noreshape');
vxyz = gather(v,(1:count(fens)),'values','noreshape');
vxyz =[xyz*skewmat([-Omegaini, 0, 0]), Omegaini+zeros(count(fens),1),zeros(count(fens),2)];
v= scatter (v,(1:count(fens)),vxyz);
a = chiincr*0; % zero out the Acceleration
utol = 1e-10*get(chiincr, 'neqns');

K = start (sparse_sysmat, get(chiincr, 'neqns'));
M = start (sparse_sysmat, get(chiincr, 'neqns'));


t=0; % time=load magnitude
while (t <= tend)
    t = t + dt;
    Report(['Time ' num2str(t) ]); % pause
    % Initialization
    chiincr = apply_ebc(chiincr);% Apply boundary conditions
    u1 = u; % guess
    Rfield1=Rfield; % guess
    du1 = 0*apply_ebc(chiincr);% Total increment in current step
    a1 = -(1/Newmarkb/dt)*v -(1/2-Newmarkb)/Newmarkb*a;
    v1 = v + dt*((1-Newmarkg)*a + Newmarkg*a1);
    dupv =gather_sysvec(dt*v +(dt^2/2*(1-2*Newmarkb))*a);
    vpv =gather_sysvec(v +(dt*(1-Newmarkg))*a);
    fi = force_intensity(struct('magn' ,q ));

    iter=1;
    while 1
        feb1=feb;
        F = start (sysvec, get(chiincr, 'neqns'));
        F = assemble (F, distrib_loads(feb, geom0, u1,Rfield1,chiincr, fi));
        [feb,evs] = restoring_force(feb,geom0,u1,Rfield1,chiincr);       % Internal forces
        F = assemble (F, evs);
        K =assemble (K,cat(2,stiffness(feb,geom0,u1,Rfield1,chiincr),stiffness_geo(feb,geom0,u1,Rfield1,chiincr)));
        Km=get(K, 'mat');
        M =assemble (M,mass(feb,geom0,u1,Rfield1,chiincr));
        Mm=get(M, 'mat');
        rhs=get(F,'vec')...
            +Mm*((-1/(Newmarkb*dt^2))*gather_sysvec(du1)+(1/(Newmarkb*dt^2))*dupv);
        chiincr = scatter_sysvec(chiincr, (Km+(1/(Newmarkb*dt^2))*Mm)\rhs); % Displacement increment
        %                 max(abs(get(F,'vec')))
        u1 = u1 + slice(chiincr,(1:3),'transl');   % increment displacement
        du1 = du1 + chiincr;
        v1 = v1 + (Newmarkg/Newmarkb/dt)*chiincr;
        a1 = a1 + (1/Newmarkb/dt^2)*chiincr;
        Rfield1=update_rotation_field(Rfield1,slice(chiincr,(4:6),'rotat'));
        Report(['   It. ' num2str(iter) ': ||du||=' num2str(norm(chiincr))]);
        if (max(abs(gather(chiincr,[],'values'))) < utol) break; end;% convergence check
        if (iter >maxit)% bailout for failed convergence
            warning( [' Possible failed convergence']);
        end
        K = reinitialize (K);
        M = reinitialize (M);
        iter=iter+1;
    end
    [feb,ignore] = restoring_force(feb,geom0,u1,Rfield1,chiincr);        % final update
    Report(['    Converged for t=' num2str(t)]); % pause
    u = u1;       % update the displacement
    Rfield=Rfield1; % update the rotations
    v = v1;       % update the velocities
    a = a1;       % update the accelerations
    
    if graphics
        gv=reset(gv,[]);
        draw(feb, gv, struct ('x', geom0, 'u', 0*u1, 'R', Rfield0, 'facecolor','r'));
        draw(feb, gv, struct ('x', geom0, 'u', u1, 'R', Rfield1, 'facecolor','g'));
        draw_local_coordinates(feb, gv, struct ('x', geom0, 'u', u1, 'R', Rfield1, 'length',12.5));
        camset(gv, 1.0e+003 *[-1.8113   -3.9366    1.7492   -0.0132    0.0090   -0.0027         0         0    0.0010    0.0019]);
        drawnow;
    else
        tipu=gather(u1,tipn, 'values', 'noreshape');
        plot(t,tipu(1), 'rv');
        hold on
        plot(t,tipu(2), 'gv');
        plot(t,tipu(3), 'bv');
        drawnow;
   end
    
    t = t + dt;
end
