function beam4nl
disp('Example BEAM4NL: small strain nonlinear analysis');
% Parameters:
E=100;
nu=0.3;
sigma_y=3;

Fmag=1/10;
scale=5;
stressscale=scale/20;
epscale=20*scale;

% Mesh
[fens,gcells] = blockx([0, 0.5, 1, 2, 4, 6, 7, 7.5, 8],[0,1],[0,1,2,3]/1.5);
% Material
prop = property_plastic_perf_j2_iso(struct('E',E,'nu',nu,'sigma_y',sigma_y));
mater = mater_ss_plastic_perf_j2_triax(struct('property',prop));
% Finite element block
feb = feblock_defor_ss_nonlinear (struct ('mater',mater, 'gcells',gcells,...
    'integration_rule',gauss_rule(3,2)));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
u   = 0*geom; % zero out
% Apply EBC's
ebc_fenids=fenode_select (fens,struct('box',[0,0,-Inf,Inf,-Inf,Inf],'inflate',1/1000));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=[];
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ebc_fenids=fenode_select (fens,struct('box',[8,8,-Inf,Inf,-Inf,Inf],'inflate',1/1000));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
% Number equations
u   = numbereqns (u);
% Assemble the system matrix
ems = stiffness(feb, geom, u, u);
K = start (dense_sysmat, get(u, 'neqns'));
K = assemble (K, ems);
% Load
F = start (sysvec, get(u, 'neqns'));
Loadedn =fenode_select(fens,struct('box',[8,8,-Inf,Inf,-Inf,Inf],'inflate',1/1000));
Fmag = Fmag*8/length(Loadedn);
for i = Loadedn
    evs = loads(nodal_load(struct('id',i,'dir',[3],'magn',[-Fmag])), u); % beam bending
    F = assemble (F, evs);
end
F = finish(F);
% Solve
a = get(K,'mat');
b = get(F,'vec');
x = a\b;
u = scatter_sysvec(u, x);
% Plot
clf;
gv=graphic_viewer;
% gm1=graphics_model(make_graphics_reps(feb, geom, u, u, 'gcells'));
% draw(gm1, 'dataidx', 3, 'scale', scale, 'displace_by', [1 2 3], 'facecolor', 'none')
% gm2=graphics_model(make_graphics_reps(feb, geom, u, u, 'integration_points'));
% draw(gm2, 'dataidx', 5, 'scale', [scale scale scale stressscale], 'displace_by', [1 2 3])
disp('Done with linear solution: hit return'); % pause


ulin = u; %  linear displacement solution

% Now comes the nonlinear solution
tup = 1;
nincr = 4;
u = u*0; % zero out the displacement
utol = 10e-12;

t=0; % time=load magnitude
incr=1;
clf;
while (incr <= nincr)
    t = t + tup / nincr;
    % Initialization
    u1 = u; % guess
    u1 = apply_ebc(u1);
    du = 0*u; % this will hold displacement increment
    du = apply_ebc(du);
    iter=1;
    clf;
    while 1
        feb1=feb;                                           % Make a copy of the state
        F = start (sysvec, get(u, 'neqns'));
        for i = Loadedn
            evs = loads(nodal_load(struct('id',i,'dir',[3],'magn',[-Fmag*t])), u); % beam bending
            F = assemble (F, evs);
        end
        [feb1,evs] = restoring_force(feb1,geom,u1,u);       % Internal forces
        F = assemble (F, evs);
        F = finish(F);
        K = dense_sysmat;
        K = start (K, get(u, 'neqns'));
        ems = stiffness(feb1, geom, u1,u);                   % Current material stiffness
        K = assemble (K, ems);
        ems = stiffness_geo(feb1, geom, u1,u);               % Current geometric stiffness
        K = assemble (K, ems);
        K = finish (K);
        % Displacement increment
        x = get(K,'mat') \ get(F,'vec');;
        du = scatter_sysvec(du, x);
        u1 = u1 + du;                                       % increment displacement
        disp(['   Iteration ' num2str(iter) ': ||du||=' num2str(norm(du))]);
        if (norm(du) < utol) break; end;                    % convergence check
        iter=iter+1;
    end
    [feb,ignore] = restoring_force(feb,geom,u1,u);        % final update
    clf;
    gv=graphic_viewer;
    gv=reset(clear(gv,[]),[]);
    draw(feb,gv, struct ('x', geom,'u',scale*u, 'facecolor','none'));
    id.comp= 1;
    id.container=-Inf;
    id=inspect_integration_points(feb, geom, u, [],...
        (1:length (gcells)), struct ('output',['equiv_pl_def']),...
        @mx,id)
    max_equiv_pl_def=id.container
    id.container=Inf;
    id=inspect_integration_points(feb, geom, u, [], ...
        (1:length (gcells)), struct ('output',['equiv_pl_def']),...
        @mn,id)
    min_equiv_pl_def =id.container
    dcm=data_colormap(struct ('range',[min_equiv_pl_def,max_equiv_pl_def], 'colormap',jet));
    draw_integration_points(feb,gv,struct ('x',geom,'u',u,'u_displ',scale*u, 'scale',0.05,'quantity',['equiv_pl_def'],'component',1,'data_cmap', dcm));
    %   draw(gm3, 'dataidx', 3, 'scale', scale, 'displace_by', [1 2 3], 'facecolor', 'none')
    %   gm4=graphics_model(make_graphics_reps(feb, geom, u1, u, ...
    %                                         'integration_points', ...
    %                                         'integration_point_quantity', 'equiv_pl_def'));
    %   draw(gm4, 'dataidx', 4, 'scale', [scale scale scale epscale], 'displace_by', [1 2 3])
    pause(1)
    disp(['Increment ' num2str(incr) ': Converged for t=' num2str(t) ':  hit return']); % pause
    u = u1;                                               % update the displacement
    incr = incr + 1;
end
end

function id= mn(id,out,xyz,pc)
    id.container=min(out(id.comp), id.container);
end

function id= mx(id,out,xyz,pc)
    id.container=max(out(id.comp), id.container);
end
%draw(gmlin, 'dataidx', 3, 'scale', scale, 'displace_by', [1 2 3], 'facecolor', 'none')