disp('LE1 NAFEMS benchmark, convergence analysis');

% Parameters:
E = 210e3;% 210e3 MPa
nu = 0.3;
p = 10;% 10 MPA Outward pressure on the outside ellipse
sigma_yD= 92.7;% tensile stress at [2.0, 0.0] meters


integration_rule = trapezoidal_rule(2);
Edge_integration_rule =trapezoidal_rule(1);
Convertf=[];
febf =@feblock_defor_ss;
Style ='ks-'; Label='Q4';

% integration_rule = simpson_1_3_rule(2);
% Edge_integration_rule =simpson_1_3_rule(1);
% Convertf=@Q4_to_Q8;
% febf =@feblock_defor_ss;
% Style ='ks-'; Label='Q8';

ns=[3,6,12,24,48]; Results = [];
% ns=[4,8,16]; Results = [];
for n=ns;% number of elements through the thickness


% Mesh'
[fens,gcells]=Q4_block(1.0,pi/2, n, n*2, struct('other_dimension', 0.1*1000));
if (~isempty( Convertf ))
  [fens,gcells] = Convertf(fens,gcells, struct('other_dimension', 0.1*1000));
end
bdry_gcells = mesh_bdry(gcells, struct('other_dimension', 0.1*1000));
icl = gcell_select(fens, bdry_gcells, struct('box', [1,1,0,pi/2],'inflate',1/100));
xy=get (fens,'xyz');
for i=1:count(fens)
    t=xy(i,1); a=xy(i,2);
    xy(i,:)=1000*[(t*3.25+(1-t)*2)*cos(a) (t*2.75+(1-t)*1)*sin(a)];
end
fens=set(fens,'xyz', xy);
% drawmesh( {fens,gcells})
% view (2)
% return
prop = property_linel_iso (struct('E',E,'nu',nu));
mater = mater_defor_ss_linel_biax (struct('property',prop, ...
  'reduction','stress'));
% Finite element block
feb = febf(struct ('mater',mater, 'gcells',gcells, 'integration_rule',integration_rule));
efeb = febf (struct ('mater',mater, 'gcells',subset(bdry_gcells,icl),...
    'integration_rule',Edge_integration_rule));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 2, 'fens',fens));
% Define the displacement field
u   = clone(geom,'u');
u   = u*0; % zero out
% Apply EBC's
% plane of symmetry
ebc_fenids=fenode_select (fens,struct('box',[0 Inf 0 0],'inflate',1/10000));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=ebc_prescribed*0+2;
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
% plane of symmetry
ebc_fenids=fenode_select (fens,struct('box',[0 0 0 Inf],'inflate',1/10000));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=ebc_prescribed*0+1;
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
% Number equations
u   = numbereqns (u);
% tic
% Assemble the system matrix
K = start (sparse_sysmat, get(u, 'neqns'));
K = assemble (K, stiffness(feb, geom, u));
% Load
fi=force_intensity(struct('magn',@(x) (p*[2.75/3.25*x(1),3.25/2.75*x(2)]'/norm([2.75/3.25*x(1),3.25/2.75*x(2)]))));
F = start (sysvec, get(u, 'neqns'));
F = assemble (F, distrib_loads(efeb, geom, u, fi, 2));
% Solve
u = scatter_sysvec(u, K\F);
% get(u,'values')
% toc, tic
% Plot
% gv=graphic_viewer;
% gv=reset (gv,struct ('limits',1000*[0 1.06*3.25 0 1.6*3.25]));
% scale=1000;
% cmap = jet;
fld = field_from_integration_points(feb, geom, u, [], 'Cauchy',2);
corner=fenode_select (fens,struct('box',1000*[2.0 2.0 0 0],'inflate',1/10000));
Approx_sigma_yD =gather (fld, corner,'values');
disp( ['n=' num2str(n) ',  Corner stress sigma_y=' num2str(Approx_sigma_yD) ' MPa'])
disp( [' i.e. ' num2str(gather(fld, corner,'values')/sigma_yD*100) '% of the Reference value'])
Results = [Results,Approx_sigma_yD];
% nvals=get(fld,'values');%min(nvals),max(nvals)
% nvalsrange=[min(nvals),max(nvals)];
% dcm=data_colormap(struct ('range',nvalsrange, 'colormap',cmap));
% colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvals)));
% draw(feb,gv, struct ('x', geom, 'u', +scale*u,'colorfield',colorfield, 'shrink',1.0));
% draw(feb,gv, struct ('x', geom, 'u', 0*u,'facecolor','none', 'shrink',1.0));
% % draw(efeb,gv, struct ('x', geom, 'u', 0*u,'facecolor','red', 'shrink',1.0));
% colormap(cmap);
% cbh=colorbar;
% set(cbh,...
%     'Position',[0.815 0.15 0.05 0.7],...
%     'YLim',[0,1],...
%     'YTick',[0,1],...
%     'YTickLabel',{[num2str(nvalsrange(1))],[num2str(nvalsrange(2))]});%{[num2str((min(nvals)))],[num2str((max(nvals)))]}
% set(get(cbh,'XLabel'),'String','\sigma_y');
% view (2)

end


h=1./ns(2:end);
Ea =diff( Results);
loglog(h,abs(Ea), 'r-o')
grid on
beta = 2.0;
C=Ea(end-1)/(h(end-1)^beta-h(end)^beta)
Ex_sigma_yD=Results(end)+C*h(end)^beta

loglog(1./ns,abs(Results-Ex_sigma_yD)/Ex_sigma_yD, 'r-o')
grid on

% integration_rule = simpson_1_3_rule(2);
% Edge_integration_rule =simpson_1_3_rule(1);
% Convertf=@Q4_to_Q8;
% febf =@feblock_defor_ss;
% Style ='ks-'; Label='Q8';
% ns= [3     6    12    24    48    96]
% Results= [  89.875976098320010  92.853550715984213  93.029698724562550  92.814638226531883  92.706647258582095] 92.671530936023160
[xestim, beta, residual] = richextrapol( Results(end-2:end),1./ns(end-2:end))
loglog(1./ns,abs(Results-xestim)/Ex_sigma_yD, 'r-o')
grid on

 assignin('caller','faesor_test_passed',((norm([93.507607538287431]-xestim))<1e-9));