disp('Taut wire: statics,  triangular load (128-b)');
L=6;
P=4;
q0= 0.1;
q =@(x)(q0*(L-x)/L);% This is consistent now with the sign convention in the textbook
n=3; % number of elements
% Mesh
[fens,gcells]= L2_block(L,n, 1.0);
[fens,gcells] = L2_to_L3(fens,gcells, []); 
% Finite element block
feb = feblock_defor_taut_wire(struct ('mater',mater,...
    'gcells',gcells,...
    'integration_rule',simpson_1_3_rule,...
    'P',P));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 1, 'fens',fens));
% Define the displacement field
w   = 0*clone(geom,'w');
% Apply EBC's
fenids=[1,n+1]; prescribed=[1,1]; component=[1,1]; val=[0,0];
w   = set_ebc(w, fenids, prescribed, component, val);
w   = apply_ebc (w);
% Number equations
w   = numbereqns (w);
% Assemble the system matrix
K = start (dense_sysmat, get(w, 'neqns'));
K = assemble (K, stiffness(feb, geom, w));
% Load
fi = force_intensity(struct ('magn',q));
F = start (sysvec, get(w, 'neqns'));
F = assemble (F, body_loads(feb, geom, w, fi));
% Solve
w = scatter_sysvec(w, get(K,'mat')\get(F,'vec'));
% Plot

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:count(gcells)
    ix=isoparamipol1d(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'));
    iw=isoparamipol1d(gcells,pc,gather(w,get(subset(gcells,j),'conn'),'values'));
    plot(ix/L,iw,'r-','linewidth',3);hold on
    x=ix;
    plot(x/L,(q0*x.^3)/(6*L*P) - (q0*x.^2)/(2*P) + (L*q0*x)/(3*P),'k:','linewidth',3);
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('w')

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:count(gcells)
    ix=isoparamipol1d(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'));
    iw=isoparamipol1d(gcells,pc,gather(w,get(subset(gcells,j),'conn'),'values'));
    x=ix;
    plot(ix/L,(q0*x.^3)/(6*L*P) - (q0*x.^2)/(2*P) + (L*q0*x)/(3*P)-iw,'r-','linewidth',3);hold on
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('w_{ex}-w')


figure; hold on;
pc=linspace(-1,+1,100);
for j=1:count(gcells)
    ix=isoparamipol1d(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'));
    iwp=isoparamipol1ddersp(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'),gather(w,get(subset(gcells,j),'conn'),'values'));
    plot(ix/L,P*iwp,'r-','linewidth',3);hold on
    x=ix;
    plot(x/L,P*((L*q0)/(3*P) - (q0*x)/P + (q0*x.^2)/(2*L*P)),'k:','linewidth',3);
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('Pw^{\prime}')

figure; hold on;
pc=linspace(-1,+1,100);
for j=1:count(gcells)
    ix=isoparamipol1d(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'));
    iwp=isoparamipol1ddersp(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'),gather(w,get(subset(gcells,j),'conn'),'values'));
    x=ix;
    plot(ix/L,P*((L*q0)/(3*P) - (q0*x)/P + (q0*x.^2)/(2*L*P))-P*iwp,'r-','linewidth',3);hold on
end
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x/L'),ylabel('Pw_{ex}^{\prime}-Pw^{\prime}')

disp('Reaction at x=0')
q(0)*L/2*(2*L/3)/L

disp(' Finite element result for the reaction')
j=1;
pc=-1;
ix=isoparamipol1d(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'));
iwp=isoparamipol1ddersp(gcells,pc,gather(geom,get(subset(gcells,j),'conn'),'values'),gather(w,get(subset(gcells,j),'conn'),'values'));
P*iwp
