% Mesh of a generally curved beam member given by the location of the
% vertices of the spline curve.
%
% function [fens,gcells] = Beam_member(xyz,nL,constructor,Parameters)
%
% xyz = M rows, one vertex location per row;
% nL = Divided into this many elements
% constructor=@gcellset_beam3
% Parameters= see gcellset_beam3
% 
function [fens,gcells] = Beam_member(xyz,nL,constructor,Parameters)
    npts=size(xyz,1);
    s=zeros(npts,1);
    for j=2:npts
        s(j)=s(j-1)+norm(xyz(j,:)-xyz(j-1,:));
    end 
    pp = spline(s',xyz');
    
    [fens,gcells] = L2_block(s(end),nL,[]);

    pxyz=get(fens,'xyz');
    nxyz=zeros(size(pxyz, 1),3);
    for i=1:count(fens)
        nxyz(i,:) = ppval(pp, pxyz(i,:));
    end
    fens=set(fens,'xyz',nxyz);
    
    % Set the cell data
    Parameters.id=get(gcells,'id');
    Parameters.conn=get(gcells,'conn');
    % Compute the Arc-length parameter along the member
    pxyz=get(fens,'xyz');
    s=zeros(size(pxyz,1),1);
    for j=2:size(pxyz,1)
        s(j)=s(j-1)+norm(pxyz(j,:)-pxyz(j-1,:));
    end 
    if (isa(Parameters.A, 'function_handle'))
        A=Parameters.A(s/s(end));
        Parameters.A=A;
    end
    if (isa(Parameters.I2, 'function_handle'))
        I2=Parameters.I2(s/s(end));
        Parameters.I2=I2;
    end
    if (isa(Parameters.I3, 'function_handle'))
        I3=Parameters.I3(s/s(end));
        Parameters.I3=I3;
    end
    if (~isfield( Parameters, 'I1' ))% in case this is not defined
        % it can be usually assumed with good accuracy to be the sum of these two
        Parameters.I1=Parameters.I2+Parameters.I3;
    end
    if (isa(Parameters.I1, 'function_handle'))
        I1=Parameters.I1(s/s(end));
        Parameters.I1=I1;
    end
    if (isa(Parameters.J, 'function_handle'))
        J=Parameters.J(s/s(end));
        Parameters.J=J;
    end
    gcells=constructor(Parameters);
end
