% Extrude a mesh of line segments into a mesh of quadrilaterals.
%
% function [fens,gcells] = L2_extrude(fens,gcells,nLayers,extrusionh)
%
% fens,gcells = nodes and cells of the L2 mesh,
% nLayers= number of layers,
% extrusionh= handle to function that computes the extrusion vector
function [fens,gcells] = L2_extrude(fens,gcells,nLayers,extrusionh)
    nn1 =count(fens);
    nnt=nn1*nLayers;
    ngc=count(gcells)*nLayers;
    xyz1=get(fens,'xyz');
    x1=extrusionh(xyz1(1,:),0)
    xyz =zeros(size(xyz1,1)*(nLayers+1),size(x1,2));
    qconn=zeros(ngc,4);
    for j=1:nn1
        xyz(j,:) =extrusionh(xyz1(j,:),0);
    end
    for k=1:nLayers
        for j=1:nn1
            f=j+k*nn1;
            xyz(f,:) =extrusionh(xyz1(j,:),k);
        end
    end
    
    conn = get(gcells,'conn');
    gc=1;
    for k=1:nLayers
        for i=1:count(gcells)
            qconn(gc,:)=[conn(i,:)+(k-1)*nn1, conn(i,end:-1:1)+k*nn1];
            gc=gc+1;
        end
    end
    gcells =gcellset_Q4(struct('id',1:ngc,'conn',qconn));
    fens =fenodeset(struct('id',1:size(xyz,1),'xyz',xyz));
end
