% Convert a mesh of Quadrilateral Q4 to Quadrilateral Q16.
%
% function [nfens,ngcells] = Q4_to_Q16(fens,gcells,options)
%
function [nfens,ngcells] = Q4_to_Q16(fens,gcells,options)
    if (count(gcells)>100)
        box=[Inf,-Inf,Inf,-Inf];
        conns = get(gcells,'conn');
        axyz=get(fens,'xyz');
        for i= 1:count(gcells)
            conn=conns(i,:);
            for k=1:length(conn)
                xyz=axyz(conn(k),:);
                box([1,3])=min([box([1,3]);xyz]);
                box([2,4])=max([box([2,4]);xyz]);
            end
        end
        dims=(box([2,4])-box([1,3]));
        sbox=box;
        if (dims(1)>dims(2)) 
            Direction =   1;
        else
            Direction =  2;
        end
        if (Direction==1)
            sbox(2)=(box(1)+box(2))/2;
        else
            sbox(4)=(box(3)+box(4))/2;
        end
        celllist1 = gcell_select(fens, gcells, struct('box',sbox));
        celllist2=setdiff((1:count(gcells)),celllist1);
%         disp([num2str(length(celllist1)) ',' num2str(length(celllist2))])
        if (length(celllist1)*length(celllist2)==0)
            [nfens,ngcells] = do_It(fens,gcells,options);
            return
        end
        [fens1,gcells1] = Q4_to_Q16(fens,subset(gcells,celllist1),options);
        [fens2,gcells2] = Q4_to_Q16(fens,subset(gcells,celllist2),options);
        [nfens,g1,g2] = merge_meshes(fens1, gcells1, fens2, gcells2, min(dims)/count(gcells)/1000);
        ngcells= cat(g1,g2);
    else
        [nfens,ngcells] = do_It(fens,gcells,options);
    end
end

function [fens,gcells] = do_It(fens,gcells,options)
    if ~isstruct(options)
        options = struct('id',1);
    end
    xyz1=get(fens,'xyz');
    allxyz= zeros(count(gcells)*16,size(xyz1,2));
    nconns=zeros(count(gcells),16);
    conns = get(gcells,'conn');
    %     number of vertex nodes
    p(1,:)=[-1,-1,-1];
    p(2,:)=[-0.333333333333333,-1,-1];
    p(3,:)=[0.333333333333333,-1,-1];
    p(4,:)=[1,-1,-1];
    p(5,:)=[-1,-0.333333333333333,-1];
    p(6,:)=[-0.333333333333333,-0.333333333333333,-1];
    p(7,:)=[0.333333333333333,-0.333333333333333,-1];
    p(8,:)=[1,-0.333333333333333,-1];
    p(9,:)=[-1,0.333333333333333,-1];
    p(10,:)=[-0.333333333333333,0.333333333333333,-1];
    p(11,:)=[0.333333333333333,0.333333333333333,-1];
    p(12,:)=[1,0.333333333333333,-1];
    p(13,:)=[-1,1,-1];
    p(14,:)=[-0.333333333333333,1,-1];
    p(15,:)=[0.333333333333333,1,-1];
    p(16,:)=[1,1,-1];
    g4=gcellset_Q4(struct('id',1,'conn',(1:4)));
    nnfens=0;
    for i= 1:count(gcells)
        conn = conns(i,:);
        xy4=zeros(4,size(xyz1,2));
        for k=1:length(conn)
            xy4(k,:)=xyz1(conn(k),:);
        end
        box=[min(xy4(:,1)),max(xy4(:,1)),min(xy4(:,2)),max(xy4(:,2))];
        tol=abs(min(box([2,4])-box([1,3])))/1000+eps;
        fenl=private_fenode_select_box(box, allxyz(1:nnfens,:),  tol);
        nconn =zeros(1, 16);
        for r=1:16
            N=bfun(g4,p(r,:));
            xyz=N'*xy4;
            pfenl=private_fenode_select(xyz, allxyz(1:nnfens,:),  tol);
            if (~isempty(pfenl))
                if (length(pfenl)~=1),error('more Than one node'),end
            else
                nnfens=nnfens+1;
                allxyz(nnfens,:)=xyz;
                pfenl=nnfens;
            end
            nconn(r)=pfenl;
        end
        nconns(i,:) =nconn;
    end
    fens=fenodeset(struct('id',1:nnfens,'xyz',allxyz(1:nnfens,:)));
    options.conn=nconns;
    gcells=gcellset_Q16(options);
end

function nodelist = private_fenode_select(xyz, allxyz,  tolerance)
    xyzd=abs([allxyz(:,1)-xyz(1),allxyz(:,2)-xyz(2)]);
    nodelist=find(sum(xyzd')'<tolerance);
end


function nodelist = private_fenode_select_box(Box, allxyz,  tolerance)
    nodelist=find(allxyz(:,1)>=Box(1));
    if (isempty(nodelist)), return, end
    nodelis1=find(allxyz(:,1)<=Box(2));
    if (isempty(nodelis1)), return, end
    nodelist =union(nodelist,nodelis1);
    if (isempty(nodelist)), return, end
    
    nodelis1=find(allxyz(:,2)>=Box(3));
    if (isempty(nodelis1)), return, end
    nodelist =union(nodelist,nodelis1);
    if (isempty(nodelist)), return, end
    nodelis1=find(allxyz(nodelist,2)<=Box(4));
    if (isempty(nodelis1)), return, end
    nodelist =union(nodelist,nodelis1);
end

